# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from typing import Dict, List, Optional
from typing_extensions import Literal, NotRequired, TypedDict


class PersonTokenCreateParams(TypedDict):
    additional_addresses: NotRequired[
        List["PersonTokenCreateParamsAdditionalAddress"]
    ]
    """
    Additional addresses associated with the person.
    """
    additional_names: NotRequired[
        List["PersonTokenCreateParamsAdditionalName"]
    ]
    """
    Additional names (e.g. aliases) associated with the person.
    """
    additional_terms_of_service: NotRequired[
        "PersonTokenCreateParamsAdditionalTermsOfService"
    ]
    """
    Attestations of accepted terms of service agreements.
    """
    address: NotRequired["PersonTokenCreateParamsAddress"]
    """
    The person's residential address.
    """
    date_of_birth: NotRequired["PersonTokenCreateParamsDateOfBirth"]
    """
    The person's date of birth.
    """
    documents: NotRequired["PersonTokenCreateParamsDocuments"]
    """
    Documents that may be submitted to satisfy various informational requests.
    """
    email: NotRequired[str]
    """
    Email.
    """
    given_name: NotRequired[str]
    """
    The person's first name.
    """
    id_numbers: NotRequired[List["PersonTokenCreateParamsIdNumber"]]
    """
    The identification numbers (e.g., SSN) associated with the person.
    """
    legal_gender: NotRequired[Literal["female", "male"]]
    """
    The person's gender (International regulations require either "male" or "female").
    """
    metadata: NotRequired[Dict[str, Optional[str]]]
    """
    Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
    """
    nationalities: NotRequired[List[str]]
    """
    The nationalities (countries) this person is associated with.
    """
    phone: NotRequired[str]
    """
    The phone number for this person.
    """
    political_exposure: NotRequired[Literal["existing", "none"]]
    """
    The person's political exposure.
    """
    relationship: NotRequired["PersonTokenCreateParamsRelationship"]
    """
    The relationship that this person has with the Account's business or legal entity.
    """
    script_addresses: NotRequired["PersonTokenCreateParamsScriptAddresses"]
    """
    The script addresses (e.g., non-Latin characters) associated with the person.
    """
    script_names: NotRequired["PersonTokenCreateParamsScriptNames"]
    """
    The script names (e.g. non-Latin characters) associated with the person.
    """
    surname: NotRequired[str]
    """
    The person's last name.
    """


class PersonTokenCreateParamsAdditionalAddress(TypedDict):
    city: NotRequired[str]
    """
    City, district, suburb, town, or village.
    """
    country: NotRequired[str]
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired[str]
    """
    Address line 1 (e.g., street, PO Box, or company name).
    """
    line2: NotRequired[str]
    """
    Address line 2 (e.g., apartment, suite, unit, or building).
    """
    postal_code: NotRequired[str]
    """
    ZIP or postal code.
    """
    purpose: Literal["registered"]
    """
    Purpose of additional address.
    """
    state: NotRequired[str]
    """
    State, county, province, or region.
    """
    town: NotRequired[str]
    """
    Town or cho-me.
    """


class PersonTokenCreateParamsAdditionalName(TypedDict):
    full_name: NotRequired[str]
    """
    The person's full name.
    """
    given_name: NotRequired[str]
    """
    The person's first or given name.
    """
    purpose: Literal["alias", "maiden"]
    """
    The purpose or type of the additional name.
    """
    surname: NotRequired[str]
    """
    The person's last or family name.
    """


class PersonTokenCreateParamsAdditionalTermsOfService(TypedDict):
    account: NotRequired[
        "PersonTokenCreateParamsAdditionalTermsOfServiceAccount"
    ]
    """
    Details on the Person's acceptance of the [Stripe Services Agreement]; IP, date, and User Agent are expanded by Stripe.
    """


class PersonTokenCreateParamsAdditionalTermsOfServiceAccount(TypedDict):
    shown_and_accepted: NotRequired[bool]
    """
    The boolean value indicating if the terms of service have been accepted.
    """


class PersonTokenCreateParamsAddress(TypedDict):
    city: NotRequired[str]
    """
    City, district, suburb, town, or village.
    """
    country: NotRequired[str]
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired[str]
    """
    Address line 1 (e.g., street, PO Box, or company name).
    """
    line2: NotRequired[str]
    """
    Address line 2 (e.g., apartment, suite, unit, or building).
    """
    postal_code: NotRequired[str]
    """
    ZIP or postal code.
    """
    state: NotRequired[str]
    """
    State, county, province, or region.
    """
    town: NotRequired[str]
    """
    Town or cho-me.
    """


class PersonTokenCreateParamsDateOfBirth(TypedDict):
    day: int
    """
    The day of the birth.
    """
    month: int
    """
    The month of birth.
    """
    year: int
    """
    The year of birth.
    """


class PersonTokenCreateParamsDocuments(TypedDict):
    company_authorization: NotRequired[
        "PersonTokenCreateParamsDocumentsCompanyAuthorization"
    ]
    """
    One or more documents that demonstrate proof that this person is authorized to represent the company.
    """
    passport: NotRequired["PersonTokenCreateParamsDocumentsPassport"]
    """
    One or more documents showing the person's passport page with photo and personal data.
    """
    primary_verification: NotRequired[
        "PersonTokenCreateParamsDocumentsPrimaryVerification"
    ]
    """
    An identifying document showing the person's name, either a passport or local ID card.
    """
    secondary_verification: NotRequired[
        "PersonTokenCreateParamsDocumentsSecondaryVerification"
    ]
    """
    A document showing address, either a passport, local ID card, or utility bill from a well-known utility company.
    """
    visa: NotRequired["PersonTokenCreateParamsDocumentsVisa"]
    """
    One or more documents showing the person's visa required for living in the country where they are residing.
    """


class PersonTokenCreateParamsDocumentsCompanyAuthorization(TypedDict):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class PersonTokenCreateParamsDocumentsPassport(TypedDict):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class PersonTokenCreateParamsDocumentsPrimaryVerification(TypedDict):
    front_back: "PersonTokenCreateParamsDocumentsPrimaryVerificationFrontBack"
    """
    The [file upload](https://docs.stripe.com/api/persons/update#create_file) tokens referring to each side of the document.
    """
    type: Literal["front_back"]
    """
    The format of the verification document. Currently supports `front_back` only.
    """


class PersonTokenCreateParamsDocumentsPrimaryVerificationFrontBack(TypedDict):
    back: NotRequired[str]
    """
    A [file upload](https://docs.stripe.com/api/persons/update#create_file) token representing the back of the verification document. The purpose of the uploaded file should be 'identity_document'. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
    """
    front: NotRequired[str]
    """
    A [file upload](https://docs.stripe.com/api/persons/update#create_file) token representing the front of the verification document. The purpose of the uploaded file should be 'identity_document'. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
    """


class PersonTokenCreateParamsDocumentsSecondaryVerification(TypedDict):
    front_back: (
        "PersonTokenCreateParamsDocumentsSecondaryVerificationFrontBack"
    )
    """
    The [file upload](https://docs.stripe.com/api/persons/update#create_file) tokens referring to each side of the document.
    """
    type: Literal["front_back"]
    """
    The format of the verification document. Currently supports `front_back` only.
    """


class PersonTokenCreateParamsDocumentsSecondaryVerificationFrontBack(
    TypedDict
):
    back: NotRequired[str]
    """
    A [file upload](https://docs.stripe.com/api/persons/update#create_file) token representing the back of the verification document. The purpose of the uploaded file should be 'identity_document'. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
    """
    front: NotRequired[str]
    """
    A [file upload](https://docs.stripe.com/api/persons/update#create_file) token representing the front of the verification document. The purpose of the uploaded file should be 'identity_document'. The uploaded file needs to be a color image (smaller than 8,000px by 8,000px), in JPG, PNG, or PDF format, and less than 10 MB in size.
    """


class PersonTokenCreateParamsDocumentsVisa(TypedDict):
    files: List[str]
    """
    One or more document IDs returned by a [file upload](https://docs.stripe.com/api/persons/update#create_file) with a purpose value of `account_requirement`.
    """
    type: Literal["files"]
    """
    The format of the document. Currently supports `files` only.
    """


class PersonTokenCreateParamsIdNumber(TypedDict):
    type: Literal[
        "ae_eid",
        "ao_nif",
        "ar_dni",
        "az_tin",
        "bd_brc",
        "bd_etin",
        "bd_nid",
        "br_cpf",
        "cr_cpf",
        "cr_dimex",
        "cr_nite",
        "de_stn",
        "do_rcn",
        "gt_nit",
        "hk_id",
        "kz_iin",
        "mx_rfc",
        "my_nric",
        "mz_nuit",
        "nl_bsn",
        "pe_dni",
        "pk_cnic",
        "pk_snic",
        "sa_tin",
        "sg_fin",
        "sg_nric",
        "th_lc",
        "th_pin",
        "us_itin",
        "us_itin_last_4",
        "us_ssn",
        "us_ssn_last_4",
    ]
    """
    The ID number type of an individual.
    """
    value: str
    """
    The value of the ID number.
    """


class PersonTokenCreateParamsRelationship(TypedDict):
    authorizer: NotRequired[bool]
    """
    Whether the individual is an authorizer of the Account's legal entity.
    """
    director: NotRequired[bool]
    """
    Indicates whether the person is a director of the associated legal entity.
    """
    executive: NotRequired[bool]
    """
    Indicates whether the person is an executive of the associated legal entity.
    """
    legal_guardian: NotRequired[bool]
    """
    Indicates whether the person is a legal guardian of the associated legal entity.
    """
    owner: NotRequired[bool]
    """
    Indicates whether the person is an owner of the associated legal entity.
    """
    percent_ownership: NotRequired[str]
    """
    The percentage of ownership the person has in the associated legal entity.
    """
    representative: NotRequired[bool]
    """
    Indicates whether the person is a representative of the associated legal entity.
    """
    title: NotRequired[str]
    """
    The title or position the person holds in the associated legal entity.
    """


class PersonTokenCreateParamsScriptAddresses(TypedDict):
    kana: NotRequired["PersonTokenCreateParamsScriptAddressesKana"]
    """
    Kana Address.
    """
    kanji: NotRequired["PersonTokenCreateParamsScriptAddressesKanji"]
    """
    Kanji Address.
    """


class PersonTokenCreateParamsScriptAddressesKana(TypedDict):
    city: NotRequired[str]
    """
    City, district, suburb, town, or village.
    """
    country: NotRequired[str]
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired[str]
    """
    Address line 1 (e.g., street, PO Box, or company name).
    """
    line2: NotRequired[str]
    """
    Address line 2 (e.g., apartment, suite, unit, or building).
    """
    postal_code: NotRequired[str]
    """
    ZIP or postal code.
    """
    state: NotRequired[str]
    """
    State, county, province, or region.
    """
    town: NotRequired[str]
    """
    Town or cho-me.
    """


class PersonTokenCreateParamsScriptAddressesKanji(TypedDict):
    city: NotRequired[str]
    """
    City, district, suburb, town, or village.
    """
    country: NotRequired[str]
    """
    Two-letter country code ([ISO 3166-1 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2)).
    """
    line1: NotRequired[str]
    """
    Address line 1 (e.g., street, PO Box, or company name).
    """
    line2: NotRequired[str]
    """
    Address line 2 (e.g., apartment, suite, unit, or building).
    """
    postal_code: NotRequired[str]
    """
    ZIP or postal code.
    """
    state: NotRequired[str]
    """
    State, county, province, or region.
    """
    town: NotRequired[str]
    """
    Town or cho-me.
    """


class PersonTokenCreateParamsScriptNames(TypedDict):
    kana: NotRequired["PersonTokenCreateParamsScriptNamesKana"]
    """
    Persons name in kana script.
    """
    kanji: NotRequired["PersonTokenCreateParamsScriptNamesKanji"]
    """
    Persons name in kanji script.
    """


class PersonTokenCreateParamsScriptNamesKana(TypedDict):
    given_name: NotRequired[str]
    """
    The person's first or given name.
    """
    surname: NotRequired[str]
    """
    The person's last or family name.
    """


class PersonTokenCreateParamsScriptNamesKanji(TypedDict):
    given_name: NotRequired[str]
    """
    The person's first or given name.
    """
    surname: NotRequired[str]
    """
    The person's last or family name.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._stripe_service import StripeService
from stripe._util import sanitize_id
from typing import Optional, cast
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe._request_options import RequestOptions
    from stripe.params.v2.money_management._transaction_list_params import (
        TransactionListParams,
    )
    from stripe.params.v2.money_management._transaction_retrieve_params import (
        TransactionRetrieveParams,
    )
    from stripe.v2._list_object import ListObject
    from stripe.v2.money_management._transaction import Transaction


class TransactionService(StripeService):
    def list(
        self,
        params: Optional["TransactionListParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[Transaction]":
        """
        Returns a list of Transactions that match the provided filters.
        """
        return cast(
            "ListObject[Transaction]",
            self._request(
                "get",
                "/v2/money_management/transactions",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def list_async(
        self,
        params: Optional["TransactionListParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[Transaction]":
        """
        Returns a list of Transactions that match the provided filters.
        """
        return cast(
            "ListObject[Transaction]",
            await self._request_async(
                "get",
                "/v2/money_management/transactions",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def retrieve(
        self,
        id: str,
        params: Optional["TransactionRetrieveParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "Transaction":
        """
        Retrieves the details of a Transaction by ID.
        """
        return cast(
            "Transaction",
            self._request(
                "get",
                "/v2/money_management/transactions/{id}".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def retrieve_async(
        self,
        id: str,
        params: Optional["TransactionRetrieveParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "Transaction":
        """
        Retrieves the details of a Transaction by ID.
        """
        return cast(
            "Transaction",
            await self._request_async(
                "get",
                "/v2/money_management/transactions/{id}".format(
                    id=sanitize_id(id),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._stripe_service import StripeService
from stripe._util import sanitize_id
from typing import Optional, cast
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe._credit_note_line_item import CreditNoteLineItem
    from stripe._list_object import ListObject
    from stripe._request_options import RequestOptions
    from stripe.params._credit_note_line_item_list_params import (
        CreditNoteLineItemListParams,
    )


class CreditNoteLineItemService(StripeService):
    def list(
        self,
        credit_note: str,
        params: Optional["CreditNoteLineItemListParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[CreditNoteLineItem]":
        """
        When retrieving a credit note, you'll get a lines property containing the first handful of those items. There is also a URL where you can retrieve the full (paginated) list of line items.
        """
        return cast(
            "ListObject[CreditNoteLineItem]",
            self._request(
                "get",
                "/v1/credit_notes/{credit_note}/lines".format(
                    credit_note=sanitize_id(credit_note),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def list_async(
        self,
        credit_note: str,
        params: Optional["CreditNoteLineItemListParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[CreditNoteLineItem]":
        """
        When retrieving a credit note, you'll get a lines property containing the first handful of those items. There is also a URL where you can retrieve the full (paginated) list of line items.
        """
        return cast(
            "ListObject[CreditNoteLineItem]",
            await self._request_async(
                "get",
                "/v1/credit_notes/{credit_note}/lines".format(
                    credit_note=sanitize_id(credit_note),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._request_options import RequestOptions
from typing import Dict, List
from typing_extensions import Literal, NotRequired


class ValueListCreateParams(RequestOptions):
    alias: str
    """
    The name of the value list for use in rules.
    """
    expand: NotRequired[List[str]]
    """
    Specifies which fields in the response should be expanded.
    """
    item_type: NotRequired[
        Literal[
            "card_bin",
            "card_fingerprint",
            "case_sensitive_string",
            "country",
            "customer_id",
            "email",
            "ip_address",
            "sepa_debit_fingerprint",
            "string",
            "us_bank_account_fingerprint",
        ]
    ]
    """
    Type of the items in the value list. One of `card_fingerprint`, `card_bin`, `email`, `ip_address`, `country`, `string`, `case_sensitive_string`, `customer_id`, `sepa_debit_fingerprint`, or `us_bank_account_fingerprint`. Use `string` if the item type is unknown or mixed.
    """
    metadata: NotRequired[Dict[str, str]]
    """
    Set of [key-value pairs](https://stripe.com/docs/api/metadata) that you can attach to an object. This can be useful for storing additional information about the object in a structured format. Individual keys can be unset by posting an empty value to them. All keys can be unset by posting an empty value to `metadata`.
    """
    name: str
    """
    The human-readable name of the value list.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe.v2.core._event import Event, EventNotification
from typing import cast
from typing_extensions import Literal, override


class V2IamApiKeyPermissionsUpdatedEventNotification(EventNotification):
    LOOKUP_TYPE = "v2.iam.api_key.permissions_updated"
    type: Literal["v2.iam.api_key.permissions_updated"]

    @override
    def fetch_event(self) -> "V2IamApiKeyPermissionsUpdatedEvent":
        return cast(
            "V2IamApiKeyPermissionsUpdatedEvent",
            super().fetch_event(),
        )

    @override
    async def fetch_event_async(self) -> "V2IamApiKeyPermissionsUpdatedEvent":
        return cast(
            "V2IamApiKeyPermissionsUpdatedEvent",
            await super().fetch_event_async(),
        )


class V2IamApiKeyPermissionsUpdatedEvent(Event):
    LOOKUP_TYPE = "v2.iam.api_key.permissions_updated"
    type: Literal["v2.iam.api_key.permissions_updated"]



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from typing import List
from typing_extensions import Literal, NotRequired, TypedDict


class ReceivedDebitCreateParams(TypedDict):
    amount: int
    """
    Amount (in cents) to be transferred.
    """
    currency: str
    """
    Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).
    """
    description: NotRequired[str]
    """
    An arbitrary string attached to the object. Often useful for displaying to users.
    """
    expand: NotRequired[List[str]]
    """
    Specifies which fields in the response should be expanded.
    """
    financial_account: str
    """
    The FinancialAccount to pull funds from.
    """
    initiating_payment_method_details: NotRequired[
        "ReceivedDebitCreateParamsInitiatingPaymentMethodDetails"
    ]
    """
    Initiating payment method details for the object.
    """
    network: Literal["ach"]
    """
    Specifies the network rails to be used. If not set, will default to the PaymentMethod's preferred network. See the [docs](https://stripe.com/docs/treasury/money-movement/timelines) to learn more about money movement timelines for each network type.
    """
    network_details: NotRequired["ReceivedDebitCreateParamsNetworkDetails"]
    """
    Details about the network used for the ReceivedDebit.
    """


class ReceivedDebitCreateParamsInitiatingPaymentMethodDetails(TypedDict):
    type: Literal["us_bank_account"]
    """
    The source type.
    """
    us_bank_account: NotRequired[
        "ReceivedDebitCreateParamsInitiatingPaymentMethodDetailsUsBankAccount"
    ]
    """
    Optional fields for `us_bank_account`.
    """


class ReceivedDebitCreateParamsInitiatingPaymentMethodDetailsUsBankAccount(
    TypedDict,
):
    account_holder_name: NotRequired[str]
    """
    The bank account holder's name.
    """
    account_number: NotRequired[str]
    """
    The bank account number.
    """
    routing_number: NotRequired[str]
    """
    The bank account's routing number.
    """


class ReceivedDebitCreateParamsNetworkDetails(TypedDict):
    ach: NotRequired["ReceivedDebitCreateParamsNetworkDetailsAch"]
    """
    Optional fields for `ach`.
    """
    type: Literal["ach"]
    """
    The type of flow that originated the ReceivedDebit.
    """


class ReceivedDebitCreateParamsNetworkDetailsAch(TypedDict):
    addenda: NotRequired[str]
    """
    Addenda record data associated with this ReceivedDebit.
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from typing_extensions import NotRequired, TypedDict

_CurrencyConversionCreateParamsBase = TypedDict(
    "CurrencyConversionCreateParams",
    {"from": "CurrencyConversionCreateParamsFrom"},
)


class CurrencyConversionCreateParams(_CurrencyConversionCreateParamsBase):
    financial_account: str
    """
    The FinancialAccount id to create the CurrencyConversion on.
    """
    to: "CurrencyConversionCreateParamsTo"
    """
    To amount object indicating the to currency or optional amount.
    """


class CurrencyConversionCreateParamsFrom(TypedDict):
    amount: NotRequired["CurrencyConversionCreateParamsFromAmount"]
    """
    Amount object.
    """
    currency: NotRequired[str]
    """
    A lowercase alpha3 currency code like "usd".
    """


class CurrencyConversionCreateParamsFromAmount(TypedDict):
    value: NotRequired[int]
    """
    A non-negative integer representing how much to charge in the [smallest currency unit](https://docs.stripe.com/currencies#minor-units).
    """
    currency: NotRequired[str]
    """
    Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).
    """


class CurrencyConversionCreateParamsTo(TypedDict):
    amount: NotRequired["CurrencyConversionCreateParamsToAmount"]
    """
    Amount object.
    """
    currency: NotRequired[str]
    """
    A lowercase alpha3 currency code like "usd".
    """


class CurrencyConversionCreateParamsToAmount(TypedDict):
    value: NotRequired[int]
    """
    A non-negative integer representing how much to charge in the [smallest currency unit](https://docs.stripe.com/currencies#minor-units).
    """
    currency: NotRequired[str]
    """
    Three-letter [ISO currency code](https://www.iso.org/iso-4217-currency-codes.html), in lowercase. Must be a [supported currency](https://stripe.com/docs/currencies).
    """



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._stripe_service import StripeService
from stripe._util import sanitize_id
from typing import Optional, cast
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe._list_object import ListObject
    from stripe._request_options import RequestOptions
    from stripe._tax_id import TaxId
    from stripe.params._tax_id_create_params import TaxIdCreateParams
    from stripe.params._tax_id_delete_params import TaxIdDeleteParams
    from stripe.params._tax_id_list_params import TaxIdListParams
    from stripe.params._tax_id_retrieve_params import TaxIdRetrieveParams


class TaxIdService(StripeService):
    def delete(
        self,
        id: str,
        params: Optional["TaxIdDeleteParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "TaxId":
        """
        Deletes an existing account or customer tax_id object.
        """
        return cast(
            "TaxId",
            self._request(
                "delete",
                "/v1/tax_ids/{id}".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def delete_async(
        self,
        id: str,
        params: Optional["TaxIdDeleteParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "TaxId":
        """
        Deletes an existing account or customer tax_id object.
        """
        return cast(
            "TaxId",
            await self._request_async(
                "delete",
                "/v1/tax_ids/{id}".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def retrieve(
        self,
        id: str,
        params: Optional["TaxIdRetrieveParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "TaxId":
        """
        Retrieves an account or customer tax_id object.
        """
        return cast(
            "TaxId",
            self._request(
                "get",
                "/v1/tax_ids/{id}".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def retrieve_async(
        self,
        id: str,
        params: Optional["TaxIdRetrieveParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "TaxId":
        """
        Retrieves an account or customer tax_id object.
        """
        return cast(
            "TaxId",
            await self._request_async(
                "get",
                "/v1/tax_ids/{id}".format(id=sanitize_id(id)),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def list(
        self,
        params: Optional["TaxIdListParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[TaxId]":
        """
        Returns a list of tax IDs.
        """
        return cast(
            "ListObject[TaxId]",
            self._request(
                "get",
                "/v1/tax_ids",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def list_async(
        self,
        params: Optional["TaxIdListParams"] = None,
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[TaxId]":
        """
        Returns a list of tax IDs.
        """
        return cast(
            "ListObject[TaxId]",
            await self._request_async(
                "get",
                "/v1/tax_ids",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    def create(
        self,
        params: "TaxIdCreateParams",
        options: Optional["RequestOptions"] = None,
    ) -> "TaxId":
        """
        Creates a new account or customer tax_id object.
        """
        return cast(
            "TaxId",
            self._request(
                "post",
                "/v1/tax_ids",
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def create_async(
        self,
        params: "TaxIdCreateParams",
        options: Optional["RequestOptions"] = None,
    ) -> "TaxId":
        """
        Creates a new account or customer tax_id object.
        """
        return cast(
            "TaxId",
            await self._request_async(
                "post",
                "/v1/tax_ids",
                base_address="api",
                params=params,
                options=options,
            ),
        )



# -*- coding: utf-8 -*-

from typing_extensions import TYPE_CHECKING
from stripe.v2.core._event import (
    UnknownEventNotification as UnknownEventNotification,
)


# The beginning of the section generated from our OpenAPI spec
from importlib import import_module

if TYPE_CHECKING:
    from stripe.events._event_classes import (
        ALL_EVENT_NOTIFICATIONS as ALL_EVENT_NOTIFICATIONS,
    )
    from stripe.events._v1_billing_meter_error_report_triggered_event import (
        V1BillingMeterErrorReportTriggeredEvent as V1BillingMeterErrorReportTriggeredEvent,
        V1BillingMeterErrorReportTriggeredEventNotification as V1BillingMeterErrorReportTriggeredEventNotification,
    )
    from stripe.events._v1_billing_meter_no_meter_found_event import (
        V1BillingMeterNoMeterFoundEvent as V1BillingMeterNoMeterFoundEvent,
        V1BillingMeterNoMeterFoundEventNotification as V1BillingMeterNoMeterFoundEventNotification,
    )
    from stripe.events._v2_billing_cadence_billed_event import (
        V2BillingCadenceBilledEvent as V2BillingCadenceBilledEvent,
        V2BillingCadenceBilledEventNotification as V2BillingCadenceBilledEventNotification,
    )
    from stripe.events._v2_billing_cadence_canceled_event import (
        V2BillingCadenceCanceledEvent as V2BillingCadenceCanceledEvent,
        V2BillingCadenceCanceledEventNotification as V2BillingCadenceCanceledEventNotification,
    )
    from stripe.events._v2_billing_cadence_created_event import (
        V2BillingCadenceCreatedEvent as V2BillingCadenceCreatedEvent,
        V2BillingCadenceCreatedEventNotification as V2BillingCadenceCreatedEventNotification,
    )
    from stripe.events._v2_billing_license_fee_created_event import (
        V2BillingLicenseFeeCreatedEvent as V2BillingLicenseFeeCreatedEvent,
        V2BillingLicenseFeeCreatedEventNotification as V2BillingLicenseFeeCreatedEventNotification,
    )
    from stripe.events._v2_billing_license_fee_updated_event import (
        V2BillingLicenseFeeUpdatedEvent as V2BillingLicenseFeeUpdatedEvent,
        V2BillingLicenseFeeUpdatedEventNotification as V2BillingLicenseFeeUpdatedEventNotification,
    )
    from stripe.events._v2_billing_license_fee_version_created_event import (
        V2BillingLicenseFeeVersionCreatedEvent as V2BillingLicenseFeeVersionCreatedEvent,
        V2BillingLicenseFeeVersionCreatedEventNotification as V2BillingLicenseFeeVersionCreatedEventNotification,
    )
    from stripe.events._v2_billing_licensed_item_created_event import (
        V2BillingLicensedItemCreatedEvent as V2BillingLicensedItemCreatedEvent,
        V2BillingLicensedItemCreatedEventNotification as V2BillingLicensedItemCreatedEventNotification,
    )
    from stripe.events._v2_billing_licensed_item_updated_event import (
        V2BillingLicensedItemUpdatedEvent as V2BillingLicensedItemUpdatedEvent,
        V2BillingLicensedItemUpdatedEventNotification as V2BillingLicensedItemUpdatedEventNotification,
    )
    from stripe.events._v2_billing_metered_item_created_event import (
        V2BillingMeteredItemCreatedEvent as V2BillingMeteredItemCreatedEvent,
        V2BillingMeteredItemCreatedEventNotification as V2BillingMeteredItemCreatedEventNotification,
    )
    from stripe.events._v2_billing_metered_item_updated_event import (
        V2BillingMeteredItemUpdatedEvent as V2BillingMeteredItemUpdatedEvent,
        V2BillingMeteredItemUpdatedEventNotification as V2BillingMeteredItemUpdatedEventNotification,
    )
    from stripe.events._v2_billing_pricing_plan_component_created_event import (
        V2BillingPricingPlanComponentCreatedEvent as V2BillingPricingPlanComponentCreatedEvent,
        V2BillingPricingPlanComponentCreatedEventNotification as V2BillingPricingPlanComponentCreatedEventNotification,
    )
    from stripe.events._v2_billing_pricing_plan_component_updated_event import (
        V2BillingPricingPlanComponentUpdatedEvent as V2BillingPricingPlanComponentUpdatedEvent,
        V2BillingPricingPlanComponentUpdatedEventNotification as V2BillingPricingPlanComponentUpdatedEventNotification,
    )
    from stripe.events._v2_billing_pricing_plan_created_event import (
        V2BillingPricingPlanCreatedEvent as V2BillingPricingPlanCreatedEvent,
        V2BillingPricingPlanCreatedEventNotification as V2BillingPricingPlanCreatedEventNotification,
    )
    from stripe.events._v2_billing_pricing_plan_subscription_collection_awaiting_customer_action_event import (
        V2BillingPricingPlanSubscriptionCollectionAwaitingCustomerActionEvent as V2BillingPricingPlanSubscriptionCollectionAwaitingCustomerActionEvent,
        V2BillingPricingPlanSubscriptionCollectionAwaitingCustomerActionEventNotification as V2BillingPricingPlanSubscriptionCollectionAwaitingCustomerActionEventNotification,
    )
    from stripe.events._v2_billing_pricing_plan_subscription_collection_current_event import (
        V2BillingPricingPlanSubscriptionCollectionCurrentEvent as V2BillingPricingPlanSubscriptionCollectionCurrentEvent,
        V2BillingPricingPlanSubscriptionCollectionCurrentEventNotification as V2BillingPricingPlanSubscriptionCollectionCurrentEventNotification,
    )
    from stripe.events._v2_billing_pricing_plan_subscription_collection_past_due_event import (
        V2BillingPricingPlanSubscriptionCollectionPastDueEvent as V2BillingPricingPlanSubscriptionCollectionPastDueEvent,
        V2BillingPricingPlanSubscriptionCollectionPastDueEventNotification as V2BillingPricingPlanSubscriptionCollectionPastDueEventNotification,
    )
    from stripe.events._v2_billing_pricing_plan_subscription_collection_paused_event import (
        V2BillingPricingPlanSubscriptionCollectionPausedEvent as V2BillingPricingPlanSubscriptionCollectionPausedEvent,
        V2BillingPricingPlanSubscriptionCollectionPausedEventNotification as V2BillingPricingPlanSubscriptionCollectionPausedEventNotification,
    )
    from stripe.events._v2_billing_pricing_plan_subscription_collection_unpaid_event import (
        V2BillingPricingPlanSubscriptionCollectionUnpaidEvent as V2BillingPricingPlanSubscriptionCollectionUnpaidEvent,
        V2BillingPricingPlanSubscriptionCollectionUnpaidEventNotification as V2BillingPricingPlanSubscriptionCollectionUnpaidEventNotification,
    )
    from stripe.events._v2_billing_pricing_plan_subscription_servicing_activated_event import (
        V2BillingPricingPlanSubscriptionServicingActivatedEvent as V2BillingPricingPlanSubscriptionServicingActivatedEvent,
        V2BillingPricingPlanSubscriptionServicingActivatedEventNotification as V2BillingPricingPlanSubscriptionServicingActivatedEventNotification,
    )
    from stripe.events._v2_billing_pricing_plan_subscription_servicing_canceled_event import (
        V2BillingPricingPlanSubscriptionServicingCanceledEvent as V2BillingPricingPlanSubscriptionServicingCanceledEvent,
        V2BillingPricingPlanSubscriptionServicingCanceledEventNotification as V2BillingPricingPlanSubscriptionServicingCanceledEventNotification,
    )
    from stripe.events._v2_billing_pricing_plan_subscription_servicing_paused_event import (
        V2BillingPricingPlanSubscriptionServicingPausedEvent as V2BillingPricingPlanSubscriptionServicingPausedEvent,
        V2BillingPricingPlanSubscriptionServicingPausedEventNotification as V2BillingPricingPlanSubscriptionServicingPausedEventNotification,
    )
    from stripe.events._v2_billing_pricing_plan_updated_event import (
        V2BillingPricingPlanUpdatedEvent as V2BillingPricingPlanUpdatedEvent,
        V2BillingPricingPlanUpdatedEventNotification as V2BillingPricingPlanUpdatedEventNotification,
    )
    from stripe.events._v2_billing_pricing_plan_version_created_event import (
        V2BillingPricingPlanVersionCreatedEvent as V2BillingPricingPlanVersionCreatedEvent,
        V2BillingPricingPlanVersionCreatedEventNotification as V2BillingPricingPlanVersionCreatedEventNotification,
    )
    from stripe.events._v2_billing_rate_card_created_event import (
        V2BillingRateCardCreatedEvent as V2BillingRateCardCreatedEvent,
        V2BillingRateCardCreatedEventNotification as V2BillingRateCardCreatedEventNotification,
    )
    from stripe.events._v2_billing_rate_card_rate_created_event import (
        V2BillingRateCardRateCreatedEvent as V2BillingRateCardRateCreatedEvent,
        V2BillingRateCardRateCreatedEventNotification as V2BillingRateCardRateCreatedEventNotification,
    )
    from stripe.events._v2_billing_rate_card_subscription_activated_event import (
        V2BillingRateCardSubscriptionActivatedEvent as V2BillingRateCardSubscriptionActivatedEvent,
        V2BillingRateCardSubscriptionActivatedEventNotification as V2BillingRateCardSubscriptionActivatedEventNotification,
    )
    from stripe.events._v2_billing_rate_card_subscription_canceled_event import (
        V2BillingRateCardSubscriptionCanceledEvent as V2BillingRateCardSubscriptionCanceledEvent,
        V2BillingRateCardSubscriptionCanceledEventNotification as V2BillingRateCardSubscriptionCanceledEventNotification,
    )
    from stripe.events._v2_billing_rate_card_subscription_collection_awaiting_customer_action_event import (
        V2BillingRateCardSubscriptionCollectionAwaitingCustomerActionEvent as V2BillingRateCardSubscriptionCollectionAwaitingCustomerActionEvent,
        V2BillingRateCardSubscriptionCollectionAwaitingCustomerActionEventNotification as V2BillingRateCardSubscriptionCollectionAwaitingCustomerActionEventNotification,
    )
    from stripe.events._v2_billing_rate_card_subscription_collection_current_event import (
        V2BillingRateCardSubscriptionCollectionCurrentEvent as V2BillingRateCardSubscriptionCollectionCurrentEvent,
        V2BillingRateCardSubscriptionCollectionCurrentEventNotification as V2BillingRateCardSubscriptionCollectionCurrentEventNotification,
    )
    from stripe.events._v2_billing_rate_card_subscription_collection_past_due_event import (
        V2BillingRateCardSubscriptionCollectionPastDueEvent as V2BillingRateCardSubscriptionCollectionPastDueEvent,
        V2BillingRateCardSubscriptionCollectionPastDueEventNotification as V2BillingRateCardSubscriptionCollectionPastDueEventNotification,
    )
    from stripe.events._v2_billing_rate_card_subscription_collection_paused_event import (
        V2BillingRateCardSubscriptionCollectionPausedEvent as V2BillingRateCardSubscriptionCollectionPausedEvent,
        V2BillingRateCardSubscriptionCollectionPausedEventNotification as V2BillingRateCardSubscriptionCollectionPausedEventNotification,
    )
    from stripe.events._v2_billing_rate_card_subscription_collection_unpaid_event import (
        V2BillingRateCardSubscriptionCollectionUnpaidEvent as V2BillingRateCardSubscriptionCollectionUnpaidEvent,
        V2BillingRateCardSubscriptionCollectionUnpaidEventNotification as V2BillingRateCardSubscriptionCollectionUnpaidEventNotification,
    )
    from stripe.events._v2_billing_rate_card_subscription_servicing_activated_event import (
        V2BillingRateCardSubscriptionServicingActivatedEvent as V2BillingRateCardSubscriptionServicingActivatedEvent,
        V2BillingRateCardSubscriptionServicingActivatedEventNotification as V2BillingRateCardSubscriptionServicingActivatedEventNotification,
    )
    from stripe.events._v2_billing_rate_card_subscription_servicing_canceled_event import (
        V2BillingRateCardSubscriptionServicingCanceledEvent as V2BillingRateCardSubscriptionServicingCanceledEvent,
        V2BillingRateCardSubscriptionServicingCanceledEventNotification as V2BillingRateCardSubscriptionServicingCanceledEventNotification,
    )
    from stripe.events._v2_billing_rate_card_subscription_servicing_paused_event import (
        V2BillingRateCardSubscriptionServicingPausedEvent as V2BillingRateCardSubscriptionServicingPausedEvent,
        V2BillingRateCardSubscriptionServicingPausedEventNotification as V2BillingRateCardSubscriptionServicingPausedEventNotification,
    )
    from stripe.events._v2_billing_rate_card_updated_event import (
        V2BillingRateCardUpdatedEvent as V2BillingRateCardUpdatedEvent,
        V2BillingRateCardUpdatedEventNotification as V2BillingRateCardUpdatedEventNotification,
    )
    from stripe.events._v2_billing_rate_card_version_created_event import (
        V2BillingRateCardVersionCreatedEvent as V2BillingRateCardVersionCreatedEvent,
        V2BillingRateCardVersionCreatedEventNotification as V2BillingRateCardVersionCreatedEventNotification,
    )
    from stripe.events._v2_core_account_closed_event import (
        V2CoreAccountClosedEvent as V2CoreAccountClosedEvent,
        V2CoreAccountClosedEventNotification as V2CoreAccountClosedEventNotification,
    )
    from stripe.events._v2_core_account_created_event import (
        V2CoreAccountCreatedEvent as V2CoreAccountCreatedEvent,
        V2CoreAccountCreatedEventNotification as V2CoreAccountCreatedEventNotification,
    )
    from stripe.events._v2_core_account_including_configuration_card_creator_capability_status_updated_event import (
        V2CoreAccountIncludingConfigurationCardCreatorCapabilityStatusUpdatedEvent as V2CoreAccountIncludingConfigurationCardCreatorCapabilityStatusUpdatedEvent,
        V2CoreAccountIncludingConfigurationCardCreatorCapabilityStatusUpdatedEventNotification as V2CoreAccountIncludingConfigurationCardCreatorCapabilityStatusUpdatedEventNotification,
    )
    from stripe.events._v2_core_account_including_configuration_card_creator_updated_event import (
        V2CoreAccountIncludingConfigurationCardCreatorUpdatedEvent as V2CoreAccountIncludingConfigurationCardCreatorUpdatedEvent,
        V2CoreAccountIncludingConfigurationCardCreatorUpdatedEventNotification as V2CoreAccountIncludingConfigurationCardCreatorUpdatedEventNotification,
    )
    from stripe.events._v2_core_account_including_configuration_customer_capability_status_updated_event import (
        V2CoreAccountIncludingConfigurationCustomerCapabilityStatusUpdatedEvent as V2CoreAccountIncludingConfigurationCustomerCapabilityStatusUpdatedEvent,
        V2CoreAccountIncludingConfigurationCustomerCapabilityStatusUpdatedEventNotification as V2CoreAccountIncludingConfigurationCustomerCapabilityStatusUpdatedEventNotification,
    )
    from stripe.events._v2_core_account_including_configuration_customer_updated_event import (
        V2CoreAccountIncludingConfigurationCustomerUpdatedEvent as V2CoreAccountIncludingConfigurationCustomerUpdatedEvent,
        V2CoreAccountIncludingConfigurationCustomerUpdatedEventNotification as V2CoreAccountIncludingConfigurationCustomerUpdatedEventNotification,
    )
    from stripe.events._v2_core_account_including_configuration_merchant_capability_status_updated_event import (
        V2CoreAccountIncludingConfigurationMerchantCapabilityStatusUpdatedEvent as V2CoreAccountIncludingConfigurationMerchantCapabilityStatusUpdatedEvent,
        V2CoreAccountIncludingConfigurationMerchantCapabilityStatusUpdatedEventNotification as V2CoreAccountIncludingConfigurationMerchantCapabilityStatusUpdatedEventNotification,
    )
    from stripe.events._v2_core_account_including_configuration_merchant_updated_event import (
        V2CoreAccountIncludingConfigurationMerchantUpdatedEvent as V2CoreAccountIncludingConfigurationMerchantUpdatedEvent,
        V2CoreAccountIncludingConfigurationMerchantUpdatedEventNotification as V2CoreAccountIncludingConfigurationMerchantUpdatedEventNotification,
    )
    from stripe.events._v2_core_account_including_configuration_recipient_capability_status_updated_event import (
        V2CoreAccountIncludingConfigurationRecipientCapabilityStatusUpdatedEvent as V2CoreAccountIncludingConfigurationRecipientCapabilityStatusUpdatedEvent,
        V2CoreAccountIncludingConfigurationRecipientCapabilityStatusUpdatedEventNotification as V2CoreAccountIncludingConfigurationRecipientCapabilityStatusUpdatedEventNotification,
    )
    from stripe.events._v2_core_account_including_configuration_recipient_updated_event import (
        V2CoreAccountIncludingConfigurationRecipientUpdatedEvent as V2CoreAccountIncludingConfigurationRecipientUpdatedEvent,
        V2CoreAccountIncludingConfigurationRecipientUpdatedEventNotification as V2CoreAccountIncludingConfigurationRecipientUpdatedEventNotification,
    )
    from stripe.events._v2_core_account_including_configuration_storer_capability_status_updated_event import (
        V2CoreAccountIncludingConfigurationStorerCapabilityStatusUpdatedEvent as V2CoreAccountIncludingConfigurationStorerCapabilityStatusUpdatedEvent,
        V2CoreAccountIncludingConfigurationStorerCapabilityStatusUpdatedEventNotification as V2CoreAccountIncludingConfigurationStorerCapabilityStatusUpdatedEventNotification,
    )
    from stripe.events._v2_core_account_including_configuration_storer_updated_event import (
        V2CoreAccountIncludingConfigurationStorerUpdatedEvent as V2CoreAccountIncludingConfigurationStorerUpdatedEvent,
        V2CoreAccountIncludingConfigurationStorerUpdatedEventNotification as V2CoreAccountIncludingConfigurationStorerUpdatedEventNotification,
    )
    from stripe.events._v2_core_account_including_defaults_updated_event import (
        V2CoreAccountIncludingDefaultsUpdatedEvent as V2CoreAccountIncludingDefaultsUpdatedEvent,
        V2CoreAccountIncludingDefaultsUpdatedEventNotification as V2CoreAccountIncludingDefaultsUpdatedEventNotification,
    )
    from stripe.events._v2_core_account_including_identity_updated_event import (
        V2CoreAccountIncludingIdentityUpdatedEvent as V2CoreAccountIncludingIdentityUpdatedEvent,
        V2CoreAccountIncludingIdentityUpdatedEventNotification as V2CoreAccountIncludingIdentityUpdatedEventNotification,
    )
    from stripe.events._v2_core_account_including_requirements_updated_event import (
        V2CoreAccountIncludingRequirementsUpdatedEvent as V2CoreAccountIncludingRequirementsUpdatedEvent,
        V2CoreAccountIncludingRequirementsUpdatedEventNotification as V2CoreAccountIncludingRequirementsUpdatedEventNotification,
    )
    from stripe.events._v2_core_account_link_returned_event import (
        V2CoreAccountLinkReturnedEvent as V2CoreAccountLinkReturnedEvent,
        V2CoreAccountLinkReturnedEventNotification as V2CoreAccountLinkReturnedEventNotification,
    )
    from stripe.events._v2_core_account_person_created_event import (
        V2CoreAccountPersonCreatedEvent as V2CoreAccountPersonCreatedEvent,
        V2CoreAccountPersonCreatedEventNotification as V2CoreAccountPersonCreatedEventNotification,
    )
    from stripe.events._v2_core_account_person_deleted_event import (
        V2CoreAccountPersonDeletedEvent as V2CoreAccountPersonDeletedEvent,
        V2CoreAccountPersonDeletedEventNotification as V2CoreAccountPersonDeletedEventNotification,
    )
    from stripe.events._v2_core_account_person_updated_event import (
        V2CoreAccountPersonUpdatedEvent as V2CoreAccountPersonUpdatedEvent,
        V2CoreAccountPersonUpdatedEventNotification as V2CoreAccountPersonUpdatedEventNotification,
    )
    from stripe.events._v2_core_account_updated_event import (
        V2CoreAccountUpdatedEvent as V2CoreAccountUpdatedEvent,
        V2CoreAccountUpdatedEventNotification as V2CoreAccountUpdatedEventNotification,
    )
    from stripe.events._v2_core_claimable_sandbox_claimed_event import (
        V2CoreClaimableSandboxClaimedEvent as V2CoreClaimableSandboxClaimedEvent,
        V2CoreClaimableSandboxClaimedEventNotification as V2CoreClaimableSandboxClaimedEventNotification,
    )
    from stripe.events._v2_core_claimable_sandbox_created_event import (
        V2CoreClaimableSandboxCreatedEvent as V2CoreClaimableSandboxCreatedEvent,
        V2CoreClaimableSandboxCreatedEventNotification as V2CoreClaimableSandboxCreatedEventNotification,
    )
    from stripe.events._v2_core_claimable_sandbox_expired_event import (
        V2CoreClaimableSandboxExpiredEvent as V2CoreClaimableSandboxExpiredEvent,
        V2CoreClaimableSandboxExpiredEventNotification as V2CoreClaimableSandboxExpiredEventNotification,
    )
    from stripe.events._v2_core_claimable_sandbox_expiring_event import (
        V2CoreClaimableSandboxExpiringEvent as V2CoreClaimableSandboxExpiringEvent,
        V2CoreClaimableSandboxExpiringEventNotification as V2CoreClaimableSandboxExpiringEventNotification,
    )
    from stripe.events._v2_core_claimable_sandbox_sandbox_details_owner_account_updated_event import (
        V2CoreClaimableSandboxSandboxDetailsOwnerAccountUpdatedEvent as V2CoreClaimableSandboxSandboxDetailsOwnerAccountUpdatedEvent,
        V2CoreClaimableSandboxSandboxDetailsOwnerAccountUpdatedEventNotification as V2CoreClaimableSandboxSandboxDetailsOwnerAccountUpdatedEventNotification,
    )
    from stripe.events._v2_core_event_destination_ping_event import (
        V2CoreEventDestinationPingEvent as V2CoreEventDestinationPingEvent,
        V2CoreEventDestinationPingEventNotification as V2CoreEventDestinationPingEventNotification,
    )
    from stripe.events._v2_core_health_api_error_firing_event import (
        V2CoreHealthApiErrorFiringEvent as V2CoreHealthApiErrorFiringEvent,
        V2CoreHealthApiErrorFiringEventNotification as V2CoreHealthApiErrorFiringEventNotification,
    )
    from stripe.events._v2_core_health_api_error_resolved_event import (
        V2CoreHealthApiErrorResolvedEvent as V2CoreHealthApiErrorResolvedEvent,
        V2CoreHealthApiErrorResolvedEventNotification as V2CoreHealthApiErrorResolvedEventNotification,
    )
    from stripe.events._v2_core_health_api_latency_firing_event import (
        V2CoreHealthApiLatencyFiringEvent as V2CoreHealthApiLatencyFiringEvent,
        V2CoreHealthApiLatencyFiringEventNotification as V2CoreHealthApiLatencyFiringEventNotification,
    )
    from stripe.events._v2_core_health_api_latency_resolved_event import (
        V2CoreHealthApiLatencyResolvedEvent as V2CoreHealthApiLatencyResolvedEvent,
        V2CoreHealthApiLatencyResolvedEventNotification as V2CoreHealthApiLatencyResolvedEventNotification,
    )
    from stripe.events._v2_core_health_authorization_rate_drop_firing_event import (
        V2CoreHealthAuthorizationRateDropFiringEvent as V2CoreHealthAuthorizationRateDropFiringEvent,
        V2CoreHealthAuthorizationRateDropFiringEventNotification as V2CoreHealthAuthorizationRateDropFiringEventNotification,
    )
    from stripe.events._v2_core_health_authorization_rate_drop_resolved_event import (
        V2CoreHealthAuthorizationRateDropResolvedEvent as V2CoreHealthAuthorizationRateDropResolvedEvent,
        V2CoreHealthAuthorizationRateDropResolvedEventNotification as V2CoreHealthAuthorizationRateDropResolvedEventNotification,
    )
    from stripe.events._v2_core_health_event_generation_failure_resolved_event import (
        V2CoreHealthEventGenerationFailureResolvedEvent as V2CoreHealthEventGenerationFailureResolvedEvent,
        V2CoreHealthEventGenerationFailureResolvedEventNotification as V2CoreHealthEventGenerationFailureResolvedEventNotification,
    )
    from stripe.events._v2_core_health_fraud_rate_increased_event import (
        V2CoreHealthFraudRateIncreasedEvent as V2CoreHealthFraudRateIncreasedEvent,
        V2CoreHealthFraudRateIncreasedEventNotification as V2CoreHealthFraudRateIncreasedEventNotification,
    )
    from stripe.events._v2_core_health_issuing_authorization_request_errors_firing_event import (
        V2CoreHealthIssuingAuthorizationRequestErrorsFiringEvent as V2CoreHealthIssuingAuthorizationRequestErrorsFiringEvent,
        V2CoreHealthIssuingAuthorizationRequestErrorsFiringEventNotification as V2CoreHealthIssuingAuthorizationRequestErrorsFiringEventNotification,
    )
    from stripe.events._v2_core_health_issuing_authorization_request_errors_resolved_event import (
        V2CoreHealthIssuingAuthorizationRequestErrorsResolvedEvent as V2CoreHealthIssuingAuthorizationRequestErrorsResolvedEvent,
        V2CoreHealthIssuingAuthorizationRequestErrorsResolvedEventNotification as V2CoreHealthIssuingAuthorizationRequestErrorsResolvedEventNotification,
    )
    from stripe.events._v2_core_health_issuing_authorization_request_timeout_firing_event import (
        V2CoreHealthIssuingAuthorizationRequestTimeoutFiringEvent as V2CoreHealthIssuingAuthorizationRequestTimeoutFiringEvent,
        V2CoreHealthIssuingAuthorizationRequestTimeoutFiringEventNotification as V2CoreHealthIssuingAuthorizationRequestTimeoutFiringEventNotification,
    )
    from stripe.events._v2_core_health_issuing_authorization_request_timeout_resolved_event import (
        V2CoreHealthIssuingAuthorizationRequestTimeoutResolvedEvent as V2CoreHealthIssuingAuthorizationRequestTimeoutResolvedEvent,
        V2CoreHealthIssuingAuthorizationRequestTimeoutResolvedEventNotification as V2CoreHealthIssuingAuthorizationRequestTimeoutResolvedEventNotification,
    )
    from stripe.events._v2_core_health_payment_method_error_firing_event import (
        V2CoreHealthPaymentMethodErrorFiringEvent as V2CoreHealthPaymentMethodErrorFiringEvent,
        V2CoreHealthPaymentMethodErrorFiringEventNotification as V2CoreHealthPaymentMethodErrorFiringEventNotification,
    )
    from stripe.events._v2_core_health_payment_method_error_resolved_event import (
        V2CoreHealthPaymentMethodErrorResolvedEvent as V2CoreHealthPaymentMethodErrorResolvedEvent,
        V2CoreHealthPaymentMethodErrorResolvedEventNotification as V2CoreHealthPaymentMethodErrorResolvedEventNotification,
    )
    from stripe.events._v2_core_health_traffic_volume_drop_firing_event import (
        V2CoreHealthTrafficVolumeDropFiringEvent as V2CoreHealthTrafficVolumeDropFiringEvent,
        V2CoreHealthTrafficVolumeDropFiringEventNotification as V2CoreHealthTrafficVolumeDropFiringEventNotification,
    )
    from stripe.events._v2_core_health_traffic_volume_drop_resolved_event import (
        V2CoreHealthTrafficVolumeDropResolvedEvent as V2CoreHealthTrafficVolumeDropResolvedEvent,
        V2CoreHealthTrafficVolumeDropResolvedEventNotification as V2CoreHealthTrafficVolumeDropResolvedEventNotification,
    )
    from stripe.events._v2_core_health_webhook_latency_firing_event import (
        V2CoreHealthWebhookLatencyFiringEvent as V2CoreHealthWebhookLatencyFiringEvent,
        V2CoreHealthWebhookLatencyFiringEventNotification as V2CoreHealthWebhookLatencyFiringEventNotification,
    )
    from stripe.events._v2_core_health_webhook_latency_resolved_event import (
        V2CoreHealthWebhookLatencyResolvedEvent as V2CoreHealthWebhookLatencyResolvedEvent,
        V2CoreHealthWebhookLatencyResolvedEventNotification as V2CoreHealthWebhookLatencyResolvedEventNotification,
    )
    from stripe.events._v2_iam_api_key_created_event import (
        V2IamApiKeyCreatedEvent as V2IamApiKeyCreatedEvent,
        V2IamApiKeyCreatedEventNotification as V2IamApiKeyCreatedEventNotification,
    )
    from stripe.events._v2_iam_api_key_default_secret_revealed_event import (
        V2IamApiKeyDefaultSecretRevealedEvent as V2IamApiKeyDefaultSecretRevealedEvent,
        V2IamApiKeyDefaultSecretRevealedEventNotification as V2IamApiKeyDefaultSecretRevealedEventNotification,
    )
    from stripe.events._v2_iam_api_key_expired_event import (
        V2IamApiKeyExpiredEvent as V2IamApiKeyExpiredEvent,
        V2IamApiKeyExpiredEventNotification as V2IamApiKeyExpiredEventNotification,
    )
    from stripe.events._v2_iam_api_key_permissions_updated_event import (
        V2IamApiKeyPermissionsUpdatedEvent as V2IamApiKeyPermissionsUpdatedEvent,
        V2IamApiKeyPermissionsUpdatedEventNotification as V2IamApiKeyPermissionsUpdatedEventNotification,
    )
    from stripe.events._v2_iam_api_key_rotated_event import (
        V2IamApiKeyRotatedEvent as V2IamApiKeyRotatedEvent,
        V2IamApiKeyRotatedEventNotification as V2IamApiKeyRotatedEventNotification,
    )
    from stripe.events._v2_iam_api_key_updated_event import (
        V2IamApiKeyUpdatedEvent as V2IamApiKeyUpdatedEvent,
        V2IamApiKeyUpdatedEventNotification as V2IamApiKeyUpdatedEventNotification,
    )
    from stripe.events._v2_money_management_adjustment_created_event import (
        V2MoneyManagementAdjustmentCreatedEvent as V2MoneyManagementAdjustmentCreatedEvent,
        V2MoneyManagementAdjustmentCreatedEventNotification as V2MoneyManagementAdjustmentCreatedEventNotification,
    )
    from stripe.events._v2_money_management_financial_account_created_event import (
        V2MoneyManagementFinancialAccountCreatedEvent as V2MoneyManagementFinancialAccountCreatedEvent,
        V2MoneyManagementFinancialAccountCreatedEventNotification as V2MoneyManagementFinancialAccountCreatedEventNotification,
    )
    from stripe.events._v2_money_management_financial_account_updated_event import (
        V2MoneyManagementFinancialAccountUpdatedEvent as V2MoneyManagementFinancialAccountUpdatedEvent,
        V2MoneyManagementFinancialAccountUpdatedEventNotification as V2MoneyManagementFinancialAccountUpdatedEventNotification,
    )
    from stripe.events._v2_money_management_financial_address_activated_event import (
        V2MoneyManagementFinancialAddressActivatedEvent as V2MoneyManagementFinancialAddressActivatedEvent,
        V2MoneyManagementFinancialAddressActivatedEventNotification as V2MoneyManagementFinancialAddressActivatedEventNotification,
    )
    from stripe.events._v2_money_management_financial_address_failed_event import (
        V2MoneyManagementFinancialAddressFailedEvent as V2MoneyManagementFinancialAddressFailedEvent,
        V2MoneyManagementFinancialAddressFailedEventNotification as V2MoneyManagementFinancialAddressFailedEventNotification,
    )
    from stripe.events._v2_money_management_inbound_transfer_available_event import (
        V2MoneyManagementInboundTransferAvailableEvent as V2MoneyManagementInboundTransferAvailableEvent,
        V2MoneyManagementInboundTransferAvailableEventNotification as V2MoneyManagementInboundTransferAvailableEventNotification,
    )
    from stripe.events._v2_money_management_inbound_transfer_bank_debit_failed_event import (
        V2MoneyManagementInboundTransferBankDebitFailedEvent as V2MoneyManagementInboundTransferBankDebitFailedEvent,
        V2MoneyManagementInboundTransferBankDebitFailedEventNotification as V2MoneyManagementInboundTransferBankDebitFailedEventNotification,
    )
    from stripe.events._v2_money_management_inbound_transfer_bank_debit_processing_event import (
        V2MoneyManagementInboundTransferBankDebitProcessingEvent as V2MoneyManagementInboundTransferBankDebitProcessingEvent,
        V2MoneyManagementInboundTransferBankDebitProcessingEventNotification as V2MoneyManagementInboundTransferBankDebitProcessingEventNotification,
    )
    from stripe.events._v2_money_management_inbound_transfer_bank_debit_queued_event import (
        V2MoneyManagementInboundTransferBankDebitQueuedEvent as V2MoneyManagementInboundTransferBankDebitQueuedEvent,
        V2MoneyManagementInboundTransferBankDebitQueuedEventNotification as V2MoneyManagementInboundTransferBankDebitQueuedEventNotification,
    )
    from stripe.events._v2_money_management_inbound_transfer_bank_debit_returned_event import (
        V2MoneyManagementInboundTransferBankDebitReturnedEvent as V2MoneyManagementInboundTransferBankDebitReturnedEvent,
        V2MoneyManagementInboundTransferBankDebitReturnedEventNotification as V2MoneyManagementInboundTransferBankDebitReturnedEventNotification,
    )
    from stripe.events._v2_money_management_inbound_transfer_bank_debit_succeeded_event import (
        V2MoneyManagementInboundTransferBankDebitSucceededEvent as V2MoneyManagementInboundTransferBankDebitSucceededEvent,
        V2MoneyManagementInboundTransferBankDebitSucceededEventNotification as V2MoneyManagementInboundTransferBankDebitSucceededEventNotification,
    )
    from stripe.events._v2_money_management_outbound_payment_canceled_event import (
        V2MoneyManagementOutboundPaymentCanceledEvent as V2MoneyManagementOutboundPaymentCanceledEvent,
        V2MoneyManagementOutboundPaymentCanceledEventNotification as V2MoneyManagementOutboundPaymentCanceledEventNotification,
    )
    from stripe.events._v2_money_management_outbound_payment_created_event import (
        V2MoneyManagementOutboundPaymentCreatedEvent as V2MoneyManagementOutboundPaymentCreatedEvent,
        V2MoneyManagementOutboundPaymentCreatedEventNotification as V2MoneyManagementOutboundPaymentCreatedEventNotification,
    )
    from stripe.events._v2_money_management_outbound_payment_failed_event import (
        V2MoneyManagementOutboundPaymentFailedEvent as V2MoneyManagementOutboundPaymentFailedEvent,
        V2MoneyManagementOutboundPaymentFailedEventNotification as V2MoneyManagementOutboundPaymentFailedEventNotification,
    )
    from stripe.events._v2_money_management_outbound_payment_posted_event import (
        V2MoneyManagementOutboundPaymentPostedEvent as V2MoneyManagementOutboundPaymentPostedEvent,
        V2MoneyManagementOutboundPaymentPostedEventNotification as V2MoneyManagementOutboundPaymentPostedEventNotification,
    )
    from stripe.events._v2_money_management_outbound_payment_returned_event import (
        V2MoneyManagementOutboundPaymentReturnedEvent as V2MoneyManagementOutboundPaymentReturnedEvent,
        V2MoneyManagementOutboundPaymentReturnedEventNotification as V2MoneyManagementOutboundPaymentReturnedEventNotification,
    )
    from stripe.events._v2_money_management_outbound_payment_updated_event import (
        V2MoneyManagementOutboundPaymentUpdatedEvent as V2MoneyManagementOutboundPaymentUpdatedEvent,
        V2MoneyManagementOutboundPaymentUpdatedEventNotification as V2MoneyManagementOutboundPaymentUpdatedEventNotification,
    )
    from stripe.events._v2_money_management_outbound_transfer_canceled_event import (
        V2MoneyManagementOutboundTransferCanceledEvent as V2MoneyManagementOutboundTransferCanceledEvent,
        V2MoneyManagementOutboundTransferCanceledEventNotification as V2MoneyManagementOutboundTransferCanceledEventNotification,
    )
    from stripe.events._v2_money_management_outbound_transfer_created_event import (
        V2MoneyManagementOutboundTransferCreatedEvent as V2MoneyManagementOutboundTransferCreatedEvent,
        V2MoneyManagementOutboundTransferCreatedEventNotification as V2MoneyManagementOutboundTransferCreatedEventNotification,
    )
    from stripe.events._v2_money_management_outbound_transfer_failed_event import (
        V2MoneyManagementOutboundTransferFailedEvent as V2MoneyManagementOutboundTransferFailedEvent,
        V2MoneyManagementOutboundTransferFailedEventNotification as V2MoneyManagementOutboundTransferFailedEventNotification,
    )
    from stripe.events._v2_money_management_outbound_transfer_posted_event import (
        V2MoneyManagementOutboundTransferPostedEvent as V2MoneyManagementOutboundTransferPostedEvent,
        V2MoneyManagementOutboundTransferPostedEventNotification as V2MoneyManagementOutboundTransferPostedEventNotification,
    )
    from stripe.events._v2_money_management_outbound_transfer_returned_event import (
        V2MoneyManagementOutboundTransferReturnedEvent as V2MoneyManagementOutboundTransferReturnedEvent,
        V2MoneyManagementOutboundTransferReturnedEventNotification as V2MoneyManagementOutboundTransferReturnedEventNotification,
    )
    from stripe.events._v2_money_management_outbound_transfer_updated_event import (
        V2MoneyManagementOutboundTransferUpdatedEvent as V2MoneyManagementOutboundTransferUpdatedEvent,
        V2MoneyManagementOutboundTransferUpdatedEventNotification as V2MoneyManagementOutboundTransferUpdatedEventNotification,
    )
    from stripe.events._v2_money_management_payout_method_updated_event import (
        V2MoneyManagementPayoutMethodUpdatedEvent as V2MoneyManagementPayoutMethodUpdatedEvent,
        V2MoneyManagementPayoutMethodUpdatedEventNotification as V2MoneyManagementPayoutMethodUpdatedEventNotification,
    )
    from stripe.events._v2_money_management_received_credit_available_event import (
        V2MoneyManagementReceivedCreditAvailableEvent as V2MoneyManagementReceivedCreditAvailableEvent,
        V2MoneyManagementReceivedCreditAvailableEventNotification as V2MoneyManagementReceivedCreditAvailableEventNotification,
    )
    from stripe.events._v2_money_management_received_credit_failed_event import (
        V2MoneyManagementReceivedCreditFailedEvent as V2MoneyManagementReceivedCreditFailedEvent,
        V2MoneyManagementReceivedCreditFailedEventNotification as V2MoneyManagementReceivedCreditFailedEventNotification,
    )
    from stripe.events._v2_money_management_received_credit_returned_event import (
        V2MoneyManagementReceivedCreditReturnedEvent as V2MoneyManagementReceivedCreditReturnedEvent,
        V2MoneyManagementReceivedCreditReturnedEventNotification as V2MoneyManagementReceivedCreditReturnedEventNotification,
    )
    from stripe.events._v2_money_management_received_credit_succeeded_event import (
        V2MoneyManagementReceivedCreditSucceededEvent as V2MoneyManagementReceivedCreditSucceededEvent,
        V2MoneyManagementReceivedCreditSucceededEventNotification as V2MoneyManagementReceivedCreditSucceededEventNotification,
    )
    from stripe.events._v2_money_management_received_debit_canceled_event import (
        V2MoneyManagementReceivedDebitCanceledEvent as V2MoneyManagementReceivedDebitCanceledEvent,
        V2MoneyManagementReceivedDebitCanceledEventNotification as V2MoneyManagementReceivedDebitCanceledEventNotification,
    )
    from stripe.events._v2_money_management_received_debit_failed_event import (
        V2MoneyManagementReceivedDebitFailedEvent as V2MoneyManagementReceivedDebitFailedEvent,
        V2MoneyManagementReceivedDebitFailedEventNotification as V2MoneyManagementReceivedDebitFailedEventNotification,
    )
    from stripe.events._v2_money_management_received_debit_pending_event import (
        V2MoneyManagementReceivedDebitPendingEvent as V2MoneyManagementReceivedDebitPendingEvent,
        V2MoneyManagementReceivedDebitPendingEventNotification as V2MoneyManagementReceivedDebitPendingEventNotification,
    )
    from stripe.events._v2_money_management_received_debit_succeeded_event import (
        V2MoneyManagementReceivedDebitSucceededEvent as V2MoneyManagementReceivedDebitSucceededEvent,
        V2MoneyManagementReceivedDebitSucceededEventNotification as V2MoneyManagementReceivedDebitSucceededEventNotification,
    )
    from stripe.events._v2_money_management_received_debit_updated_event import (
        V2MoneyManagementReceivedDebitUpdatedEvent as V2MoneyManagementReceivedDebitUpdatedEvent,
        V2MoneyManagementReceivedDebitUpdatedEventNotification as V2MoneyManagementReceivedDebitUpdatedEventNotification,
    )
    from stripe.events._v2_money_management_recipient_verification_created_event import (
        V2MoneyManagementRecipientVerificationCreatedEvent as V2MoneyManagementRecipientVerificationCreatedEvent,
        V2MoneyManagementRecipientVerificationCreatedEventNotification as V2MoneyManagementRecipientVerificationCreatedEventNotification,
    )
    from stripe.events._v2_money_management_recipient_verification_updated_event import (
        V2MoneyManagementRecipientVerificationUpdatedEvent as V2MoneyManagementRecipientVerificationUpdatedEvent,
        V2MoneyManagementRecipientVerificationUpdatedEventNotification as V2MoneyManagementRecipientVerificationUpdatedEventNotification,
    )
    from stripe.events._v2_money_management_transaction_created_event import (
        V2MoneyManagementTransactionCreatedEvent as V2MoneyManagementTransactionCreatedEvent,
        V2MoneyManagementTransactionCreatedEventNotification as V2MoneyManagementTransactionCreatedEventNotification,
    )
    from stripe.events._v2_money_management_transaction_updated_event import (
        V2MoneyManagementTransactionUpdatedEvent as V2MoneyManagementTransactionUpdatedEvent,
        V2MoneyManagementTransactionUpdatedEventNotification as V2MoneyManagementTransactionUpdatedEventNotification,
    )
    from stripe.events._v2_payments_off_session_payment_attempt_failed_event import (
        V2PaymentsOffSessionPaymentAttemptFailedEvent as V2PaymentsOffSessionPaymentAttemptFailedEvent,
        V2PaymentsOffSessionPaymentAttemptFailedEventNotification as V2PaymentsOffSessionPaymentAttemptFailedEventNotification,
    )
    from stripe.events._v2_payments_off_session_payment_attempt_started_event import (
        V2PaymentsOffSessionPaymentAttemptStartedEvent as V2PaymentsOffSessionPaymentAttemptStartedEvent,
        V2PaymentsOffSessionPaymentAttemptStartedEventNotification as V2PaymentsOffSessionPaymentAttemptStartedEventNotification,
    )
    from stripe.events._v2_payments_off_session_payment_authorization_attempt_failed_event import (
        V2PaymentsOffSessionPaymentAuthorizationAttemptFailedEvent as V2PaymentsOffSessionPaymentAuthorizationAttemptFailedEvent,
        V2PaymentsOffSessionPaymentAuthorizationAttemptFailedEventNotification as V2PaymentsOffSessionPaymentAuthorizationAttemptFailedEventNotification,
    )
    from stripe.events._v2_payments_off_session_payment_authorization_attempt_started_event import (
        V2PaymentsOffSessionPaymentAuthorizationAttemptStartedEvent as V2PaymentsOffSessionPaymentAuthorizationAttemptStartedEvent,
        V2PaymentsOffSessionPaymentAuthorizationAttemptStartedEventNotification as V2PaymentsOffSessionPaymentAuthorizationAttemptStartedEventNotification,
    )
    from stripe.events._v2_payments_off_session_payment_canceled_event import (
        V2PaymentsOffSessionPaymentCanceledEvent as V2PaymentsOffSessionPaymentCanceledEvent,
        V2PaymentsOffSessionPaymentCanceledEventNotification as V2PaymentsOffSessionPaymentCanceledEventNotification,
    )
    from stripe.events._v2_payments_off_session_payment_created_event import (
        V2PaymentsOffSessionPaymentCreatedEvent as V2PaymentsOffSessionPaymentCreatedEvent,
        V2PaymentsOffSessionPaymentCreatedEventNotification as V2PaymentsOffSessionPaymentCreatedEventNotification,
    )
    from stripe.events._v2_payments_off_session_payment_failed_event import (
        V2PaymentsOffSessionPaymentFailedEvent as V2PaymentsOffSessionPaymentFailedEvent,
        V2PaymentsOffSessionPaymentFailedEventNotification as V2PaymentsOffSessionPaymentFailedEventNotification,
    )
    from stripe.events._v2_payments_off_session_payment_requires_capture_event import (
        V2PaymentsOffSessionPaymentRequiresCaptureEvent as V2PaymentsOffSessionPaymentRequiresCaptureEvent,
        V2PaymentsOffSessionPaymentRequiresCaptureEventNotification as V2PaymentsOffSessionPaymentRequiresCaptureEventNotification,
    )
    from stripe.events._v2_payments_off_session_payment_succeeded_event import (
        V2PaymentsOffSessionPaymentSucceededEvent as V2PaymentsOffSessionPaymentSucceededEvent,
        V2PaymentsOffSessionPaymentSucceededEventNotification as V2PaymentsOffSessionPaymentSucceededEventNotification,
    )
    from stripe.events._v2_reporting_report_run_created_event import (
        V2ReportingReportRunCreatedEvent as V2ReportingReportRunCreatedEvent,
        V2ReportingReportRunCreatedEventNotification as V2ReportingReportRunCreatedEventNotification,
    )
    from stripe.events._v2_reporting_report_run_failed_event import (
        V2ReportingReportRunFailedEvent as V2ReportingReportRunFailedEvent,
        V2ReportingReportRunFailedEventNotification as V2ReportingReportRunFailedEventNotification,
    )
    from stripe.events._v2_reporting_report_run_succeeded_event import (
        V2ReportingReportRunSucceededEvent as V2ReportingReportRunSucceededEvent,
        V2ReportingReportRunSucceededEventNotification as V2ReportingReportRunSucceededEventNotification,
    )
    from stripe.events._v2_reporting_report_run_updated_event import (
        V2ReportingReportRunUpdatedEvent as V2ReportingReportRunUpdatedEvent,
        V2ReportingReportRunUpdatedEventNotification as V2ReportingReportRunUpdatedEventNotification,
    )

# name -> (import_target, is_submodule)
_import_map = {
    "ALL_EVENT_NOTIFICATIONS": ("stripe.events._event_classes", False),
    "V1BillingMeterErrorReportTriggeredEvent": (
        "stripe.events._v1_billing_meter_error_report_triggered_event",
        False,
    ),
    "V1BillingMeterErrorReportTriggeredEventNotification": (
        "stripe.events._v1_billing_meter_error_report_triggered_event",
        False,
    ),
    "V1BillingMeterNoMeterFoundEvent": (
        "stripe.events._v1_billing_meter_no_meter_found_event",
        False,
    ),
    "V1BillingMeterNoMeterFoundEventNotification": (
        "stripe.events._v1_billing_meter_no_meter_found_event",
        False,
    ),
    "V2BillingCadenceBilledEvent": (
        "stripe.events._v2_billing_cadence_billed_event",
        False,
    ),
    "V2BillingCadenceBilledEventNotification": (
        "stripe.events._v2_billing_cadence_billed_event",
        False,
    ),
    "V2BillingCadenceCanceledEvent": (
        "stripe.events._v2_billing_cadence_canceled_event",
        False,
    ),
    "V2BillingCadenceCanceledEventNotification": (
        "stripe.events._v2_billing_cadence_canceled_event",
        False,
    ),
    "V2BillingCadenceCreatedEvent": (
        "stripe.events._v2_billing_cadence_created_event",
        False,
    ),
    "V2BillingCadenceCreatedEventNotification": (
        "stripe.events._v2_billing_cadence_created_event",
        False,
    ),
    "V2BillingLicenseFeeCreatedEvent": (
        "stripe.events._v2_billing_license_fee_created_event",
        False,
    ),
    "V2BillingLicenseFeeCreatedEventNotification": (
        "stripe.events._v2_billing_license_fee_created_event",
        False,
    ),
    "V2BillingLicenseFeeUpdatedEvent": (
        "stripe.events._v2_billing_license_fee_updated_event",
        False,
    ),
    "V2BillingLicenseFeeUpdatedEventNotification": (
        "stripe.events._v2_billing_license_fee_updated_event",
        False,
    ),
    "V2BillingLicenseFeeVersionCreatedEvent": (
        "stripe.events._v2_billing_license_fee_version_created_event",
        False,
    ),
    "V2BillingLicenseFeeVersionCreatedEventNotification": (
        "stripe.events._v2_billing_license_fee_version_created_event",
        False,
    ),
    "V2BillingLicensedItemCreatedEvent": (
        "stripe.events._v2_billing_licensed_item_created_event",
        False,
    ),
    "V2BillingLicensedItemCreatedEventNotification": (
        "stripe.events._v2_billing_licensed_item_created_event",
        False,
    ),
    "V2BillingLicensedItemUpdatedEvent": (
        "stripe.events._v2_billing_licensed_item_updated_event",
        False,
    ),
    "V2BillingLicensedItemUpdatedEventNotification": (
        "stripe.events._v2_billing_licensed_item_updated_event",
        False,
    ),
    "V2BillingMeteredItemCreatedEvent": (
        "stripe.events._v2_billing_metered_item_created_event",
        False,
    ),
    "V2BillingMeteredItemCreatedEventNotification": (
        "stripe.events._v2_billing_metered_item_created_event",
        False,
    ),
    "V2BillingMeteredItemUpdatedEvent": (
        "stripe.events._v2_billing_metered_item_updated_event",
        False,
    ),
    "V2BillingMeteredItemUpdatedEventNotification": (
        "stripe.events._v2_billing_metered_item_updated_event",
        False,
    ),
    "V2BillingPricingPlanComponentCreatedEvent": (
        "stripe.events._v2_billing_pricing_plan_component_created_event",
        False,
    ),
    "V2BillingPricingPlanComponentCreatedEventNotification": (
        "stripe.events._v2_billing_pricing_plan_component_created_event",
        False,
    ),
    "V2BillingPricingPlanComponentUpdatedEvent": (
        "stripe.events._v2_billing_pricing_plan_component_updated_event",
        False,
    ),
    "V2BillingPricingPlanComponentUpdatedEventNotification": (
        "stripe.events._v2_billing_pricing_plan_component_updated_event",
        False,
    ),
    "V2BillingPricingPlanCreatedEvent": (
        "stripe.events._v2_billing_pricing_plan_created_event",
        False,
    ),
    "V2BillingPricingPlanCreatedEventNotification": (
        "stripe.events._v2_billing_pricing_plan_created_event",
        False,
    ),
    "V2BillingPricingPlanSubscriptionCollectionAwaitingCustomerActionEvent": (
        "stripe.events._v2_billing_pricing_plan_subscription_collection_awaiting_customer_action_event",
        False,
    ),
    "V2BillingPricingPlanSubscriptionCollectionAwaitingCustomerActionEventNotification": (
        "stripe.events._v2_billing_pricing_plan_subscription_collection_awaiting_customer_action_event",
        False,
    ),
    "V2BillingPricingPlanSubscriptionCollectionCurrentEvent": (
        "stripe.events._v2_billing_pricing_plan_subscription_collection_current_event",
        False,
    ),
    "V2BillingPricingPlanSubscriptionCollectionCurrentEventNotification": (
        "stripe.events._v2_billing_pricing_plan_subscription_collection_current_event",
        False,
    ),
    "V2BillingPricingPlanSubscriptionCollectionPastDueEvent": (
        "stripe.events._v2_billing_pricing_plan_subscription_collection_past_due_event",
        False,
    ),
    "V2BillingPricingPlanSubscriptionCollectionPastDueEventNotification": (
        "stripe.events._v2_billing_pricing_plan_subscription_collection_past_due_event",
        False,
    ),
    "V2BillingPricingPlanSubscriptionCollectionPausedEvent": (
        "stripe.events._v2_billing_pricing_plan_subscription_collection_paused_event",
        False,
    ),
    "V2BillingPricingPlanSubscriptionCollectionPausedEventNotification": (
        "stripe.events._v2_billing_pricing_plan_subscription_collection_paused_event",
        False,
    ),
    "V2BillingPricingPlanSubscriptionCollectionUnpaidEvent": (
        "stripe.events._v2_billing_pricing_plan_subscription_collection_unpaid_event",
        False,
    ),
    "V2BillingPricingPlanSubscriptionCollectionUnpaidEventNotification": (
        "stripe.events._v2_billing_pricing_plan_subscription_collection_unpaid_event",
        False,
    ),
    "V2BillingPricingPlanSubscriptionServicingActivatedEvent": (
        "stripe.events._v2_billing_pricing_plan_subscription_servicing_activated_event",
        False,
    ),
    "V2BillingPricingPlanSubscriptionServicingActivatedEventNotification": (
        "stripe.events._v2_billing_pricing_plan_subscription_servicing_activated_event",
        False,
    ),
    "V2BillingPricingPlanSubscriptionServicingCanceledEvent": (
        "stripe.events._v2_billing_pricing_plan_subscription_servicing_canceled_event",
        False,
    ),
    "V2BillingPricingPlanSubscriptionServicingCanceledEventNotification": (
        "stripe.events._v2_billing_pricing_plan_subscription_servicing_canceled_event",
        False,
    ),
    "V2BillingPricingPlanSubscriptionServicingPausedEvent": (
        "stripe.events._v2_billing_pricing_plan_subscription_servicing_paused_event",
        False,
    ),
    "V2BillingPricingPlanSubscriptionServicingPausedEventNotification": (
        "stripe.events._v2_billing_pricing_plan_subscription_servicing_paused_event",
        False,
    ),
    "V2BillingPricingPlanUpdatedEvent": (
        "stripe.events._v2_billing_pricing_plan_updated_event",
        False,
    ),
    "V2BillingPricingPlanUpdatedEventNotification": (
        "stripe.events._v2_billing_pricing_plan_updated_event",
        False,
    ),
    "V2BillingPricingPlanVersionCreatedEvent": (
        "stripe.events._v2_billing_pricing_plan_version_created_event",
        False,
    ),
    "V2BillingPricingPlanVersionCreatedEventNotification": (
        "stripe.events._v2_billing_pricing_plan_version_created_event",
        False,
    ),
    "V2BillingRateCardCreatedEvent": (
        "stripe.events._v2_billing_rate_card_created_event",
        False,
    ),
    "V2BillingRateCardCreatedEventNotification": (
        "stripe.events._v2_billing_rate_card_created_event",
        False,
    ),
    "V2BillingRateCardRateCreatedEvent": (
        "stripe.events._v2_billing_rate_card_rate_created_event",
        False,
    ),
    "V2BillingRateCardRateCreatedEventNotification": (
        "stripe.events._v2_billing_rate_card_rate_created_event",
        False,
    ),
    "V2BillingRateCardSubscriptionActivatedEvent": (
        "stripe.events._v2_billing_rate_card_subscription_activated_event",
        False,
    ),
    "V2BillingRateCardSubscriptionActivatedEventNotification": (
        "stripe.events._v2_billing_rate_card_subscription_activated_event",
        False,
    ),
    "V2BillingRateCardSubscriptionCanceledEvent": (
        "stripe.events._v2_billing_rate_card_subscription_canceled_event",
        False,
    ),
    "V2BillingRateCardSubscriptionCanceledEventNotification": (
        "stripe.events._v2_billing_rate_card_subscription_canceled_event",
        False,
    ),
    "V2BillingRateCardSubscriptionCollectionAwaitingCustomerActionEvent": (
        "stripe.events._v2_billing_rate_card_subscription_collection_awaiting_customer_action_event",
        False,
    ),
    "V2BillingRateCardSubscriptionCollectionAwaitingCustomerActionEventNotification": (
        "stripe.events._v2_billing_rate_card_subscription_collection_awaiting_customer_action_event",
        False,
    ),
    "V2BillingRateCardSubscriptionCollectionCurrentEvent": (
        "stripe.events._v2_billing_rate_card_subscription_collection_current_event",
        False,
    ),
    "V2BillingRateCardSubscriptionCollectionCurrentEventNotification": (
        "stripe.events._v2_billing_rate_card_subscription_collection_current_event",
        False,
    ),
    "V2BillingRateCardSubscriptionCollectionPastDueEvent": (
        "stripe.events._v2_billing_rate_card_subscription_collection_past_due_event",
        False,
    ),
    "V2BillingRateCardSubscriptionCollectionPastDueEventNotification": (
        "stripe.events._v2_billing_rate_card_subscription_collection_past_due_event",
        False,
    ),
    "V2BillingRateCardSubscriptionCollectionPausedEvent": (
        "stripe.events._v2_billing_rate_card_subscription_collection_paused_event",
        False,
    ),
    "V2BillingRateCardSubscriptionCollectionPausedEventNotification": (
        "stripe.events._v2_billing_rate_card_subscription_collection_paused_event",
        False,
    ),
    "V2BillingRateCardSubscriptionCollectionUnpaidEvent": (
        "stripe.events._v2_billing_rate_card_subscription_collection_unpaid_event",
        False,
    ),
    "V2BillingRateCardSubscriptionCollectionUnpaidEventNotification": (
        "stripe.events._v2_billing_rate_card_subscription_collection_unpaid_event",
        False,
    ),
    "V2BillingRateCardSubscriptionServicingActivatedEvent": (
        "stripe.events._v2_billing_rate_card_subscription_servicing_activated_event",
        False,
    ),
    "V2BillingRateCardSubscriptionServicingActivatedEventNotification": (
        "stripe.events._v2_billing_rate_card_subscription_servicing_activated_event",
        False,
    ),
    "V2BillingRateCardSubscriptionServicingCanceledEvent": (
        "stripe.events._v2_billing_rate_card_subscription_servicing_canceled_event",
        False,
    ),
    "V2BillingRateCardSubscriptionServicingCanceledEventNotification": (
        "stripe.events._v2_billing_rate_card_subscription_servicing_canceled_event",
        False,
    ),
    "V2BillingRateCardSubscriptionServicingPausedEvent": (
        "stripe.events._v2_billing_rate_card_subscription_servicing_paused_event",
        False,
    ),
    "V2BillingRateCardSubscriptionServicingPausedEventNotification": (
        "stripe.events._v2_billing_rate_card_subscription_servicing_paused_event",
        False,
    ),
    "V2BillingRateCardUpdatedEvent": (
        "stripe.events._v2_billing_rate_card_updated_event",
        False,
    ),
    "V2BillingRateCardUpdatedEventNotification": (
        "stripe.events._v2_billing_rate_card_updated_event",
        False,
    ),
    "V2BillingRateCardVersionCreatedEvent": (
        "stripe.events._v2_billing_rate_card_version_created_event",
        False,
    ),
    "V2BillingRateCardVersionCreatedEventNotification": (
        "stripe.events._v2_billing_rate_card_version_created_event",
        False,
    ),
    "V2CoreAccountClosedEvent": (
        "stripe.events._v2_core_account_closed_event",
        False,
    ),
    "V2CoreAccountClosedEventNotification": (
        "stripe.events._v2_core_account_closed_event",
        False,
    ),
    "V2CoreAccountCreatedEvent": (
        "stripe.events._v2_core_account_created_event",
        False,
    ),
    "V2CoreAccountCreatedEventNotification": (
        "stripe.events._v2_core_account_created_event",
        False,
    ),
    "V2CoreAccountIncludingConfigurationCardCreatorCapabilityStatusUpdatedEvent": (
        "stripe.events._v2_core_account_including_configuration_card_creator_capability_status_updated_event",
        False,
    ),
    "V2CoreAccountIncludingConfigurationCardCreatorCapabilityStatusUpdatedEventNotification": (
        "stripe.events._v2_core_account_including_configuration_card_creator_capability_status_updated_event",
        False,
    ),
    "V2CoreAccountIncludingConfigurationCardCreatorUpdatedEvent": (
        "stripe.events._v2_core_account_including_configuration_card_creator_updated_event",
        False,
    ),
    "V2CoreAccountIncludingConfigurationCardCreatorUpdatedEventNotification": (
        "stripe.events._v2_core_account_including_configuration_card_creator_updated_event",
        False,
    ),
    "V2CoreAccountIncludingConfigurationCustomerCapabilityStatusUpdatedEvent": (
        "stripe.events._v2_core_account_including_configuration_customer_capability_status_updated_event",
        False,
    ),
    "V2CoreAccountIncludingConfigurationCustomerCapabilityStatusUpdatedEventNotification": (
        "stripe.events._v2_core_account_including_configuration_customer_capability_status_updated_event",
        False,
    ),
    "V2CoreAccountIncludingConfigurationCustomerUpdatedEvent": (
        "stripe.events._v2_core_account_including_configuration_customer_updated_event",
        False,
    ),
    "V2CoreAccountIncludingConfigurationCustomerUpdatedEventNotification": (
        "stripe.events._v2_core_account_including_configuration_customer_updated_event",
        False,
    ),
    "V2CoreAccountIncludingConfigurationMerchantCapabilityStatusUpdatedEvent": (
        "stripe.events._v2_core_account_including_configuration_merchant_capability_status_updated_event",
        False,
    ),
    "V2CoreAccountIncludingConfigurationMerchantCapabilityStatusUpdatedEventNotification": (
        "stripe.events._v2_core_account_including_configuration_merchant_capability_status_updated_event",
        False,
    ),
    "V2CoreAccountIncludingConfigurationMerchantUpdatedEvent": (
        "stripe.events._v2_core_account_including_configuration_merchant_updated_event",
        False,
    ),
    "V2CoreAccountIncludingConfigurationMerchantUpdatedEventNotification": (
        "stripe.events._v2_core_account_including_configuration_merchant_updated_event",
        False,
    ),
    "V2CoreAccountIncludingConfigurationRecipientCapabilityStatusUpdatedEvent": (
        "stripe.events._v2_core_account_including_configuration_recipient_capability_status_updated_event",
        False,
    ),
    "V2CoreAccountIncludingConfigurationRecipientCapabilityStatusUpdatedEventNotification": (
        "stripe.events._v2_core_account_including_configuration_recipient_capability_status_updated_event",
        False,
    ),
    "V2CoreAccountIncludingConfigurationRecipientUpdatedEvent": (
        "stripe.events._v2_core_account_including_configuration_recipient_updated_event",
        False,
    ),
    "V2CoreAccountIncludingConfigurationRecipientUpdatedEventNotification": (
        "stripe.events._v2_core_account_including_configuration_recipient_updated_event",
        False,
    ),
    "V2CoreAccountIncludingConfigurationStorerCapabilityStatusUpdatedEvent": (
        "stripe.events._v2_core_account_including_configuration_storer_capability_status_updated_event",
        False,
    ),
    "V2CoreAccountIncludingConfigurationStorerCapabilityStatusUpdatedEventNotification": (
        "stripe.events._v2_core_account_including_configuration_storer_capability_status_updated_event",
        False,
    ),
    "V2CoreAccountIncludingConfigurationStorerUpdatedEvent": (
        "stripe.events._v2_core_account_including_configuration_storer_updated_event",
        False,
    ),
    "V2CoreAccountIncludingConfigurationStorerUpdatedEventNotification": (
        "stripe.events._v2_core_account_including_configuration_storer_updated_event",
        False,
    ),
    "V2CoreAccountIncludingDefaultsUpdatedEvent": (
        "stripe.events._v2_core_account_including_defaults_updated_event",
        False,
    ),
    "V2CoreAccountIncludingDefaultsUpdatedEventNotification": (
        "stripe.events._v2_core_account_including_defaults_updated_event",
        False,
    ),
    "V2CoreAccountIncludingIdentityUpdatedEvent": (
        "stripe.events._v2_core_account_including_identity_updated_event",
        False,
    ),
    "V2CoreAccountIncludingIdentityUpdatedEventNotification": (
        "stripe.events._v2_core_account_including_identity_updated_event",
        False,
    ),
    "V2CoreAccountIncludingRequirementsUpdatedEvent": (
        "stripe.events._v2_core_account_including_requirements_updated_event",
        False,
    ),
    "V2CoreAccountIncludingRequirementsUpdatedEventNotification": (
        "stripe.events._v2_core_account_including_requirements_updated_event",
        False,
    ),
    "V2CoreAccountLinkReturnedEvent": (
        "stripe.events._v2_core_account_link_returned_event",
        False,
    ),
    "V2CoreAccountLinkReturnedEventNotification": (
        "stripe.events._v2_core_account_link_returned_event",
        False,
    ),
    "V2CoreAccountPersonCreatedEvent": (
        "stripe.events._v2_core_account_person_created_event",
        False,
    ),
    "V2CoreAccountPersonCreatedEventNotification": (
        "stripe.events._v2_core_account_person_created_event",
        False,
    ),
    "V2CoreAccountPersonDeletedEvent": (
        "stripe.events._v2_core_account_person_deleted_event",
        False,
    ),
    "V2CoreAccountPersonDeletedEventNotification": (
        "stripe.events._v2_core_account_person_deleted_event",
        False,
    ),
    "V2CoreAccountPersonUpdatedEvent": (
        "stripe.events._v2_core_account_person_updated_event",
        False,
    ),
    "V2CoreAccountPersonUpdatedEventNotification": (
        "stripe.events._v2_core_account_person_updated_event",
        False,
    ),
    "V2CoreAccountUpdatedEvent": (
        "stripe.events._v2_core_account_updated_event",
        False,
    ),
    "V2CoreAccountUpdatedEventNotification": (
        "stripe.events._v2_core_account_updated_event",
        False,
    ),
    "V2CoreClaimableSandboxClaimedEvent": (
        "stripe.events._v2_core_claimable_sandbox_claimed_event",
        False,
    ),
    "V2CoreClaimableSandboxClaimedEventNotification": (
        "stripe.events._v2_core_claimable_sandbox_claimed_event",
        False,
    ),
    "V2CoreClaimableSandboxCreatedEvent": (
        "stripe.events._v2_core_claimable_sandbox_created_event",
        False,
    ),
    "V2CoreClaimableSandboxCreatedEventNotification": (
        "stripe.events._v2_core_claimable_sandbox_created_event",
        False,
    ),
    "V2CoreClaimableSandboxExpiredEvent": (
        "stripe.events._v2_core_claimable_sandbox_expired_event",
        False,
    ),
    "V2CoreClaimableSandboxExpiredEventNotification": (
        "stripe.events._v2_core_claimable_sandbox_expired_event",
        False,
    ),
    "V2CoreClaimableSandboxExpiringEvent": (
        "stripe.events._v2_core_claimable_sandbox_expiring_event",
        False,
    ),
    "V2CoreClaimableSandboxExpiringEventNotification": (
        "stripe.events._v2_core_claimable_sandbox_expiring_event",
        False,
    ),
    "V2CoreClaimableSandboxSandboxDetailsOwnerAccountUpdatedEvent": (
        "stripe.events._v2_core_claimable_sandbox_sandbox_details_owner_account_updated_event",
        False,
    ),
    "V2CoreClaimableSandboxSandboxDetailsOwnerAccountUpdatedEventNotification": (
        "stripe.events._v2_core_claimable_sandbox_sandbox_details_owner_account_updated_event",
        False,
    ),
    "V2CoreEventDestinationPingEvent": (
        "stripe.events._v2_core_event_destination_ping_event",
        False,
    ),
    "V2CoreEventDestinationPingEventNotification": (
        "stripe.events._v2_core_event_destination_ping_event",
        False,
    ),
    "V2CoreHealthApiErrorFiringEvent": (
        "stripe.events._v2_core_health_api_error_firing_event",
        False,
    ),
    "V2CoreHealthApiErrorFiringEventNotification": (
        "stripe.events._v2_core_health_api_error_firing_event",
        False,
    ),
    "V2CoreHealthApiErrorResolvedEvent": (
        "stripe.events._v2_core_health_api_error_resolved_event",
        False,
    ),
    "V2CoreHealthApiErrorResolvedEventNotification": (
        "stripe.events._v2_core_health_api_error_resolved_event",
        False,
    ),
    "V2CoreHealthApiLatencyFiringEvent": (
        "stripe.events._v2_core_health_api_latency_firing_event",
        False,
    ),
    "V2CoreHealthApiLatencyFiringEventNotification": (
        "stripe.events._v2_core_health_api_latency_firing_event",
        False,
    ),
    "V2CoreHealthApiLatencyResolvedEvent": (
        "stripe.events._v2_core_health_api_latency_resolved_event",
        False,
    ),
    "V2CoreHealthApiLatencyResolvedEventNotification": (
        "stripe.events._v2_core_health_api_latency_resolved_event",
        False,
    ),
    "V2CoreHealthAuthorizationRateDropFiringEvent": (
        "stripe.events._v2_core_health_authorization_rate_drop_firing_event",
        False,
    ),
    "V2CoreHealthAuthorizationRateDropFiringEventNotification": (
        "stripe.events._v2_core_health_authorization_rate_drop_firing_event",
        False,
    ),
    "V2CoreHealthAuthorizationRateDropResolvedEvent": (
        "stripe.events._v2_core_health_authorization_rate_drop_resolved_event",
        False,
    ),
    "V2CoreHealthAuthorizationRateDropResolvedEventNotification": (
        "stripe.events._v2_core_health_authorization_rate_drop_resolved_event",
        False,
    ),
    "V2CoreHealthEventGenerationFailureResolvedEvent": (
        "stripe.events._v2_core_health_event_generation_failure_resolved_event",
        False,
    ),
    "V2CoreHealthEventGenerationFailureResolvedEventNotification": (
        "stripe.events._v2_core_health_event_generation_failure_resolved_event",
        False,
    ),
    "V2CoreHealthFraudRateIncreasedEvent": (
        "stripe.events._v2_core_health_fraud_rate_increased_event",
        False,
    ),
    "V2CoreHealthFraudRateIncreasedEventNotification": (
        "stripe.events._v2_core_health_fraud_rate_increased_event",
        False,
    ),
    "V2CoreHealthIssuingAuthorizationRequestErrorsFiringEvent": (
        "stripe.events._v2_core_health_issuing_authorization_request_errors_firing_event",
        False,
    ),
    "V2CoreHealthIssuingAuthorizationRequestErrorsFiringEventNotification": (
        "stripe.events._v2_core_health_issuing_authorization_request_errors_firing_event",
        False,
    ),
    "V2CoreHealthIssuingAuthorizationRequestErrorsResolvedEvent": (
        "stripe.events._v2_core_health_issuing_authorization_request_errors_resolved_event",
        False,
    ),
    "V2CoreHealthIssuingAuthorizationRequestErrorsResolvedEventNotification": (
        "stripe.events._v2_core_health_issuing_authorization_request_errors_resolved_event",
        False,
    ),
    "V2CoreHealthIssuingAuthorizationRequestTimeoutFiringEvent": (
        "stripe.events._v2_core_health_issuing_authorization_request_timeout_firing_event",
        False,
    ),
    "V2CoreHealthIssuingAuthorizationRequestTimeoutFiringEventNotification": (
        "stripe.events._v2_core_health_issuing_authorization_request_timeout_firing_event",
        False,
    ),
    "V2CoreHealthIssuingAuthorizationRequestTimeoutResolvedEvent": (
        "stripe.events._v2_core_health_issuing_authorization_request_timeout_resolved_event",
        False,
    ),
    "V2CoreHealthIssuingAuthorizationRequestTimeoutResolvedEventNotification": (
        "stripe.events._v2_core_health_issuing_authorization_request_timeout_resolved_event",
        False,
    ),
    "V2CoreHealthPaymentMethodErrorFiringEvent": (
        "stripe.events._v2_core_health_payment_method_error_firing_event",
        False,
    ),
    "V2CoreHealthPaymentMethodErrorFiringEventNotification": (
        "stripe.events._v2_core_health_payment_method_error_firing_event",
        False,
    ),
    "V2CoreHealthPaymentMethodErrorResolvedEvent": (
        "stripe.events._v2_core_health_payment_method_error_resolved_event",
        False,
    ),
    "V2CoreHealthPaymentMethodErrorResolvedEventNotification": (
        "stripe.events._v2_core_health_payment_method_error_resolved_event",
        False,
    ),
    "V2CoreHealthTrafficVolumeDropFiringEvent": (
        "stripe.events._v2_core_health_traffic_volume_drop_firing_event",
        False,
    ),
    "V2CoreHealthTrafficVolumeDropFiringEventNotification": (
        "stripe.events._v2_core_health_traffic_volume_drop_firing_event",
        False,
    ),
    "V2CoreHealthTrafficVolumeDropResolvedEvent": (
        "stripe.events._v2_core_health_traffic_volume_drop_resolved_event",
        False,
    ),
    "V2CoreHealthTrafficVolumeDropResolvedEventNotification": (
        "stripe.events._v2_core_health_traffic_volume_drop_resolved_event",
        False,
    ),
    "V2CoreHealthWebhookLatencyFiringEvent": (
        "stripe.events._v2_core_health_webhook_latency_firing_event",
        False,
    ),
    "V2CoreHealthWebhookLatencyFiringEventNotification": (
        "stripe.events._v2_core_health_webhook_latency_firing_event",
        False,
    ),
    "V2CoreHealthWebhookLatencyResolvedEvent": (
        "stripe.events._v2_core_health_webhook_latency_resolved_event",
        False,
    ),
    "V2CoreHealthWebhookLatencyResolvedEventNotification": (
        "stripe.events._v2_core_health_webhook_latency_resolved_event",
        False,
    ),
    "V2IamApiKeyCreatedEvent": (
        "stripe.events._v2_iam_api_key_created_event",
        False,
    ),
    "V2IamApiKeyCreatedEventNotification": (
        "stripe.events._v2_iam_api_key_created_event",
        False,
    ),
    "V2IamApiKeyDefaultSecretRevealedEvent": (
        "stripe.events._v2_iam_api_key_default_secret_revealed_event",
        False,
    ),
    "V2IamApiKeyDefaultSecretRevealedEventNotification": (
        "stripe.events._v2_iam_api_key_default_secret_revealed_event",
        False,
    ),
    "V2IamApiKeyExpiredEvent": (
        "stripe.events._v2_iam_api_key_expired_event",
        False,
    ),
    "V2IamApiKeyExpiredEventNotification": (
        "stripe.events._v2_iam_api_key_expired_event",
        False,
    ),
    "V2IamApiKeyPermissionsUpdatedEvent": (
        "stripe.events._v2_iam_api_key_permissions_updated_event",
        False,
    ),
    "V2IamApiKeyPermissionsUpdatedEventNotification": (
        "stripe.events._v2_iam_api_key_permissions_updated_event",
        False,
    ),
    "V2IamApiKeyRotatedEvent": (
        "stripe.events._v2_iam_api_key_rotated_event",
        False,
    ),
    "V2IamApiKeyRotatedEventNotification": (
        "stripe.events._v2_iam_api_key_rotated_event",
        False,
    ),
    "V2IamApiKeyUpdatedEvent": (
        "stripe.events._v2_iam_api_key_updated_event",
        False,
    ),
    "V2IamApiKeyUpdatedEventNotification": (
        "stripe.events._v2_iam_api_key_updated_event",
        False,
    ),
    "V2MoneyManagementAdjustmentCreatedEvent": (
        "stripe.events._v2_money_management_adjustment_created_event",
        False,
    ),
    "V2MoneyManagementAdjustmentCreatedEventNotification": (
        "stripe.events._v2_money_management_adjustment_created_event",
        False,
    ),
    "V2MoneyManagementFinancialAccountCreatedEvent": (
        "stripe.events._v2_money_management_financial_account_created_event",
        False,
    ),
    "V2MoneyManagementFinancialAccountCreatedEventNotification": (
        "stripe.events._v2_money_management_financial_account_created_event",
        False,
    ),
    "V2MoneyManagementFinancialAccountUpdatedEvent": (
        "stripe.events._v2_money_management_financial_account_updated_event",
        False,
    ),
    "V2MoneyManagementFinancialAccountUpdatedEventNotification": (
        "stripe.events._v2_money_management_financial_account_updated_event",
        False,
    ),
    "V2MoneyManagementFinancialAddressActivatedEvent": (
        "stripe.events._v2_money_management_financial_address_activated_event",
        False,
    ),
    "V2MoneyManagementFinancialAddressActivatedEventNotification": (
        "stripe.events._v2_money_management_financial_address_activated_event",
        False,
    ),
    "V2MoneyManagementFinancialAddressFailedEvent": (
        "stripe.events._v2_money_management_financial_address_failed_event",
        False,
    ),
    "V2MoneyManagementFinancialAddressFailedEventNotification": (
        "stripe.events._v2_money_management_financial_address_failed_event",
        False,
    ),
    "V2MoneyManagementInboundTransferAvailableEvent": (
        "stripe.events._v2_money_management_inbound_transfer_available_event",
        False,
    ),
    "V2MoneyManagementInboundTransferAvailableEventNotification": (
        "stripe.events._v2_money_management_inbound_transfer_available_event",
        False,
    ),
    "V2MoneyManagementInboundTransferBankDebitFailedEvent": (
        "stripe.events._v2_money_management_inbound_transfer_bank_debit_failed_event",
        False,
    ),
    "V2MoneyManagementInboundTransferBankDebitFailedEventNotification": (
        "stripe.events._v2_money_management_inbound_transfer_bank_debit_failed_event",
        False,
    ),
    "V2MoneyManagementInboundTransferBankDebitProcessingEvent": (
        "stripe.events._v2_money_management_inbound_transfer_bank_debit_processing_event",
        False,
    ),
    "V2MoneyManagementInboundTransferBankDebitProcessingEventNotification": (
        "stripe.events._v2_money_management_inbound_transfer_bank_debit_processing_event",
        False,
    ),
    "V2MoneyManagementInboundTransferBankDebitQueuedEvent": (
        "stripe.events._v2_money_management_inbound_transfer_bank_debit_queued_event",
        False,
    ),
    "V2MoneyManagementInboundTransferBankDebitQueuedEventNotification": (
        "stripe.events._v2_money_management_inbound_transfer_bank_debit_queued_event",
        False,
    ),
    "V2MoneyManagementInboundTransferBankDebitReturnedEvent": (
        "stripe.events._v2_money_management_inbound_transfer_bank_debit_returned_event",
        False,
    ),
    "V2MoneyManagementInboundTransferBankDebitReturnedEventNotification": (
        "stripe.events._v2_money_management_inbound_transfer_bank_debit_returned_event",
        False,
    ),
    "V2MoneyManagementInboundTransferBankDebitSucceededEvent": (
        "stripe.events._v2_money_management_inbound_transfer_bank_debit_succeeded_event",
        False,
    ),
    "V2MoneyManagementInboundTransferBankDebitSucceededEventNotification": (
        "stripe.events._v2_money_management_inbound_transfer_bank_debit_succeeded_event",
        False,
    ),
    "V2MoneyManagementOutboundPaymentCanceledEvent": (
        "stripe.events._v2_money_management_outbound_payment_canceled_event",
        False,
    ),
    "V2MoneyManagementOutboundPaymentCanceledEventNotification": (
        "stripe.events._v2_money_management_outbound_payment_canceled_event",
        False,
    ),
    "V2MoneyManagementOutboundPaymentCreatedEvent": (
        "stripe.events._v2_money_management_outbound_payment_created_event",
        False,
    ),
    "V2MoneyManagementOutboundPaymentCreatedEventNotification": (
        "stripe.events._v2_money_management_outbound_payment_created_event",
        False,
    ),
    "V2MoneyManagementOutboundPaymentFailedEvent": (
        "stripe.events._v2_money_management_outbound_payment_failed_event",
        False,
    ),
    "V2MoneyManagementOutboundPaymentFailedEventNotification": (
        "stripe.events._v2_money_management_outbound_payment_failed_event",
        False,
    ),
    "V2MoneyManagementOutboundPaymentPostedEvent": (
        "stripe.events._v2_money_management_outbound_payment_posted_event",
        False,
    ),
    "V2MoneyManagementOutboundPaymentPostedEventNotification": (
        "stripe.events._v2_money_management_outbound_payment_posted_event",
        False,
    ),
    "V2MoneyManagementOutboundPaymentReturnedEvent": (
        "stripe.events._v2_money_management_outbound_payment_returned_event",
        False,
    ),
    "V2MoneyManagementOutboundPaymentReturnedEventNotification": (
        "stripe.events._v2_money_management_outbound_payment_returned_event",
        False,
    ),
    "V2MoneyManagementOutboundPaymentUpdatedEvent": (
        "stripe.events._v2_money_management_outbound_payment_updated_event",
        False,
    ),
    "V2MoneyManagementOutboundPaymentUpdatedEventNotification": (
        "stripe.events._v2_money_management_outbound_payment_updated_event",
        False,
    ),
    "V2MoneyManagementOutboundTransferCanceledEvent": (
        "stripe.events._v2_money_management_outbound_transfer_canceled_event",
        False,
    ),
    "V2MoneyManagementOutboundTransferCanceledEventNotification": (
        "stripe.events._v2_money_management_outbound_transfer_canceled_event",
        False,
    ),
    "V2MoneyManagementOutboundTransferCreatedEvent": (
        "stripe.events._v2_money_management_outbound_transfer_created_event",
        False,
    ),
    "V2MoneyManagementOutboundTransferCreatedEventNotification": (
        "stripe.events._v2_money_management_outbound_transfer_created_event",
        False,
    ),
    "V2MoneyManagementOutboundTransferFailedEvent": (
        "stripe.events._v2_money_management_outbound_transfer_failed_event",
        False,
    ),
    "V2MoneyManagementOutboundTransferFailedEventNotification": (
        "stripe.events._v2_money_management_outbound_transfer_failed_event",
        False,
    ),
    "V2MoneyManagementOutboundTransferPostedEvent": (
        "stripe.events._v2_money_management_outbound_transfer_posted_event",
        False,
    ),
    "V2MoneyManagementOutboundTransferPostedEventNotification": (
        "stripe.events._v2_money_management_outbound_transfer_posted_event",
        False,
    ),
    "V2MoneyManagementOutboundTransferReturnedEvent": (
        "stripe.events._v2_money_management_outbound_transfer_returned_event",
        False,
    ),
    "V2MoneyManagementOutboundTransferReturnedEventNotification": (
        "stripe.events._v2_money_management_outbound_transfer_returned_event",
        False,
    ),
    "V2MoneyManagementOutboundTransferUpdatedEvent": (
        "stripe.events._v2_money_management_outbound_transfer_updated_event",
        False,
    ),
    "V2MoneyManagementOutboundTransferUpdatedEventNotification": (
        "stripe.events._v2_money_management_outbound_transfer_updated_event",
        False,
    ),
    "V2MoneyManagementPayoutMethodUpdatedEvent": (
        "stripe.events._v2_money_management_payout_method_updated_event",
        False,
    ),
    "V2MoneyManagementPayoutMethodUpdatedEventNotification": (
        "stripe.events._v2_money_management_payout_method_updated_event",
        False,
    ),
    "V2MoneyManagementReceivedCreditAvailableEvent": (
        "stripe.events._v2_money_management_received_credit_available_event",
        False,
    ),
    "V2MoneyManagementReceivedCreditAvailableEventNotification": (
        "stripe.events._v2_money_management_received_credit_available_event",
        False,
    ),
    "V2MoneyManagementReceivedCreditFailedEvent": (
        "stripe.events._v2_money_management_received_credit_failed_event",
        False,
    ),
    "V2MoneyManagementReceivedCreditFailedEventNotification": (
        "stripe.events._v2_money_management_received_credit_failed_event",
        False,
    ),
    "V2MoneyManagementReceivedCreditReturnedEvent": (
        "stripe.events._v2_money_management_received_credit_returned_event",
        False,
    ),
    "V2MoneyManagementReceivedCreditReturnedEventNotification": (
        "stripe.events._v2_money_management_received_credit_returned_event",
        False,
    ),
    "V2MoneyManagementReceivedCreditSucceededEvent": (
        "stripe.events._v2_money_management_received_credit_succeeded_event",
        False,
    ),
    "V2MoneyManagementReceivedCreditSucceededEventNotification": (
        "stripe.events._v2_money_management_received_credit_succeeded_event",
        False,
    ),
    "V2MoneyManagementReceivedDebitCanceledEvent": (
        "stripe.events._v2_money_management_received_debit_canceled_event",
        False,
    ),
    "V2MoneyManagementReceivedDebitCanceledEventNotification": (
        "stripe.events._v2_money_management_received_debit_canceled_event",
        False,
    ),
    "V2MoneyManagementReceivedDebitFailedEvent": (
        "stripe.events._v2_money_management_received_debit_failed_event",
        False,
    ),
    "V2MoneyManagementReceivedDebitFailedEventNotification": (
        "stripe.events._v2_money_management_received_debit_failed_event",
        False,
    ),
    "V2MoneyManagementReceivedDebitPendingEvent": (
        "stripe.events._v2_money_management_received_debit_pending_event",
        False,
    ),
    "V2MoneyManagementReceivedDebitPendingEventNotification": (
        "stripe.events._v2_money_management_received_debit_pending_event",
        False,
    ),
    "V2MoneyManagementReceivedDebitSucceededEvent": (
        "stripe.events._v2_money_management_received_debit_succeeded_event",
        False,
    ),
    "V2MoneyManagementReceivedDebitSucceededEventNotification": (
        "stripe.events._v2_money_management_received_debit_succeeded_event",
        False,
    ),
    "V2MoneyManagementReceivedDebitUpdatedEvent": (
        "stripe.events._v2_money_management_received_debit_updated_event",
        False,
    ),
    "V2MoneyManagementReceivedDebitUpdatedEventNotification": (
        "stripe.events._v2_money_management_received_debit_updated_event",
        False,
    ),
    "V2MoneyManagementRecipientVerificationCreatedEvent": (
        "stripe.events._v2_money_management_recipient_verification_created_event",
        False,
    ),
    "V2MoneyManagementRecipientVerificationCreatedEventNotification": (
        "stripe.events._v2_money_management_recipient_verification_created_event",
        False,
    ),
    "V2MoneyManagementRecipientVerificationUpdatedEvent": (
        "stripe.events._v2_money_management_recipient_verification_updated_event",
        False,
    ),
    "V2MoneyManagementRecipientVerificationUpdatedEventNotification": (
        "stripe.events._v2_money_management_recipient_verification_updated_event",
        False,
    ),
    "V2MoneyManagementTransactionCreatedEvent": (
        "stripe.events._v2_money_management_transaction_created_event",
        False,
    ),
    "V2MoneyManagementTransactionCreatedEventNotification": (
        "stripe.events._v2_money_management_transaction_created_event",
        False,
    ),
    "V2MoneyManagementTransactionUpdatedEvent": (
        "stripe.events._v2_money_management_transaction_updated_event",
        False,
    ),
    "V2MoneyManagementTransactionUpdatedEventNotification": (
        "stripe.events._v2_money_management_transaction_updated_event",
        False,
    ),
    "V2PaymentsOffSessionPaymentAttemptFailedEvent": (
        "stripe.events._v2_payments_off_session_payment_attempt_failed_event",
        False,
    ),
    "V2PaymentsOffSessionPaymentAttemptFailedEventNotification": (
        "stripe.events._v2_payments_off_session_payment_attempt_failed_event",
        False,
    ),
    "V2PaymentsOffSessionPaymentAttemptStartedEvent": (
        "stripe.events._v2_payments_off_session_payment_attempt_started_event",
        False,
    ),
    "V2PaymentsOffSessionPaymentAttemptStartedEventNotification": (
        "stripe.events._v2_payments_off_session_payment_attempt_started_event",
        False,
    ),
    "V2PaymentsOffSessionPaymentAuthorizationAttemptFailedEvent": (
        "stripe.events._v2_payments_off_session_payment_authorization_attempt_failed_event",
        False,
    ),
    "V2PaymentsOffSessionPaymentAuthorizationAttemptFailedEventNotification": (
        "stripe.events._v2_payments_off_session_payment_authorization_attempt_failed_event",
        False,
    ),
    "V2PaymentsOffSessionPaymentAuthorizationAttemptStartedEvent": (
        "stripe.events._v2_payments_off_session_payment_authorization_attempt_started_event",
        False,
    ),
    "V2PaymentsOffSessionPaymentAuthorizationAttemptStartedEventNotification": (
        "stripe.events._v2_payments_off_session_payment_authorization_attempt_started_event",
        False,
    ),
    "V2PaymentsOffSessionPaymentCanceledEvent": (
        "stripe.events._v2_payments_off_session_payment_canceled_event",
        False,
    ),
    "V2PaymentsOffSessionPaymentCanceledEventNotification": (
        "stripe.events._v2_payments_off_session_payment_canceled_event",
        False,
    ),
    "V2PaymentsOffSessionPaymentCreatedEvent": (
        "stripe.events._v2_payments_off_session_payment_created_event",
        False,
    ),
    "V2PaymentsOffSessionPaymentCreatedEventNotification": (
        "stripe.events._v2_payments_off_session_payment_created_event",
        False,
    ),
    "V2PaymentsOffSessionPaymentFailedEvent": (
        "stripe.events._v2_payments_off_session_payment_failed_event",
        False,
    ),
    "V2PaymentsOffSessionPaymentFailedEventNotification": (
        "stripe.events._v2_payments_off_session_payment_failed_event",
        False,
    ),
    "V2PaymentsOffSessionPaymentRequiresCaptureEvent": (
        "stripe.events._v2_payments_off_session_payment_requires_capture_event",
        False,
    ),
    "V2PaymentsOffSessionPaymentRequiresCaptureEventNotification": (
        "stripe.events._v2_payments_off_session_payment_requires_capture_event",
        False,
    ),
    "V2PaymentsOffSessionPaymentSucceededEvent": (
        "stripe.events._v2_payments_off_session_payment_succeeded_event",
        False,
    ),
    "V2PaymentsOffSessionPaymentSucceededEventNotification": (
        "stripe.events._v2_payments_off_session_payment_succeeded_event",
        False,
    ),
    "V2ReportingReportRunCreatedEvent": (
        "stripe.events._v2_reporting_report_run_created_event",
        False,
    ),
    "V2ReportingReportRunCreatedEventNotification": (
        "stripe.events._v2_reporting_report_run_created_event",
        False,
    ),
    "V2ReportingReportRunFailedEvent": (
        "stripe.events._v2_reporting_report_run_failed_event",
        False,
    ),
    "V2ReportingReportRunFailedEventNotification": (
        "stripe.events._v2_reporting_report_run_failed_event",
        False,
    ),
    "V2ReportingReportRunSucceededEvent": (
        "stripe.events._v2_reporting_report_run_succeeded_event",
        False,
    ),
    "V2ReportingReportRunSucceededEventNotification": (
        "stripe.events._v2_reporting_report_run_succeeded_event",
        False,
    ),
    "V2ReportingReportRunUpdatedEvent": (
        "stripe.events._v2_reporting_report_run_updated_event",
        False,
    ),
    "V2ReportingReportRunUpdatedEventNotification": (
        "stripe.events._v2_reporting_report_run_updated_event",
        False,
    ),
}
if not TYPE_CHECKING:

    def __getattr__(name):
        try:
            target, is_submodule = _import_map[name]
            module = import_module(target)
            if is_submodule:
                return module

            return getattr(
                module,
                name,
            )
        except KeyError:
            raise AttributeError()

# The end of the section generated from our OpenAPI spec



# -*- coding: utf-8 -*-
# File generated from our OpenAPI spec
from stripe._stripe_service import StripeService
from stripe._util import sanitize_id
from typing import Optional, cast
from typing_extensions import TYPE_CHECKING

if TYPE_CHECKING:
    from stripe._list_object import ListObject
    from stripe._request_options import RequestOptions
    from stripe.financial_connections._account_owner import AccountOwner
    from stripe.params.financial_connections._account_owner_list_params import (
        AccountOwnerListParams,
    )


class AccountOwnerService(StripeService):
    def list(
        self,
        account: str,
        params: "AccountOwnerListParams",
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[AccountOwner]":
        """
        Lists all owners for a given Account
        """
        return cast(
            "ListObject[AccountOwner]",
            self._request(
                "get",
                "/v1/financial_connections/accounts/{account}/owners".format(
                    account=sanitize_id(account),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )

    async def list_async(
        self,
        account: str,
        params: "AccountOwnerListParams",
        options: Optional["RequestOptions"] = None,
    ) -> "ListObject[AccountOwner]":
        """
        Lists all owners for a given Account
        """
        return cast(
            "ListObject[AccountOwner]",
            await self._request_async(
                "get",
                "/v1/financial_connections/accounts/{account}/owners".format(
                    account=sanitize_id(account),
                ),
                base_address="api",
                params=params,
                options=options,
            ),
        )
